.gr-prose {
	color: #374151;
	max-width: 65ch;
}
.gr-prose [class~="lead"] {
	color: #4b5563;
	font-size: 1.25em;
	line-height: 1.6;
	margin-top: 1.2em;
	margin-bottom: 1.2em;
}
.gr-prose a {
	color: #111827;
	text-decoration: underline;
	font-weight: 500;
}
.gr-prose strong {
	color: #111827;
	font-weight: 600;
}
.gr-prose ol[type="A"] {
	--list-counter-style: upper-alpha;
}
.gr-prose ol[type="a"] {
	--list-counter-style: lower-alpha;
}
.gr-prose ol[type="A"s] {
	--list-counter-style: upper-alpha;
}
.gr-prose ol[type="a"s] {
	--list-counter-style: lower-alpha;
}
.gr-prose ol[type="I"] {
	--list-counter-style: upper-roman;
}
.gr-prose ol[type="i"] {
	--list-counter-style: lower-roman;
}
.gr-prose ol[type="I"s] {
	--list-counter-style: upper-roman;
}
.gr-prose ol[type="i"s] {
	--list-counter-style: lower-roman;
}
.gr-prose ol[type="1"] {
	--list-counter-style: decimal;
}
.gr-prose ol > li {
	position: relative;
	padding-left: 1.75em;
}
.gr-prose ol > li::before {
	content: counter(list-item, var(--list-counter-style, decimal)) ".";
	position: absolute;
	font-weight: 400;
	color: #6b7280;
	left: 0;
}
.gr-prose ul > li {
	position: relative;
	padding-left: 1.75em;
}
.gr-prose ul > li::before {
	content: "";
	position: absolute;
	background-color: #d1d5db;
	border-radius: 50%;
	width: 0.375em;
	height: 0.375em;
	top: calc(0.875em - 0.1875em);
	left: 0.25em;
}
.gr-prose hr {
	border-color: #e5e7eb;
	border-top-width: 1px;
	margin-top: 3em;
	margin-bottom: 3em;
}
.gr-prose blockquote {
	font-weight: 500;
	font-style: italic;
	color: #111827;
	border-left-width: 0.25rem;
	border-left-color: #e5e7eb;
	quotes: "\201C""\201D""\2018""\2019";
	margin-top: 1.6em;
	margin-bottom: 1.6em;
	padding-left: 1em;
}
.gr-prose blockquote p:first-of-type::before {
	content: open-quote;
}
.gr-prose blockquote p:last-of-type::after {
	content: close-quote;
}
.gr-prose h1 {
	color: #111827;
	font-weight: 600;
	font-size: 2.25em;
	margin-top: 0;
	margin-bottom: 0.8888889em;
	line-height: 1.1111111;
}
.gr-prose h2 {
	color: #111827;
	font-weight: 600;
	font-size: 1.5em;
	margin-top: 2em;
	margin-bottom: 1em;
	line-height: 1.3333333;
}
.gr-prose h3 {
	color: #111827;
	font-weight: 600;
	font-size: 1.25em;
	margin-top: 1.6em;
	margin-bottom: 0.6em;
	line-height: 1.6;
}
.gr-prose h4 {
	color: #111827;
	font-weight: 600;
	margin-top: 1.5em;
	margin-bottom: 0.5em;
	line-height: 1.5;
}
.gr-prose figure figcaption {
	color: #6b7280;
	font-size: 0.875em;
	line-height: 1.4285714;
	margin-top: 0.8571429em;
}
.gr-prose code {
	color: #111827;
	font-weight: 600;
	font-size: 0.875em;
}
.gr-prose code::before {
	content: "`";
}
.gr-prose code::after {
	content: "`";
}
.gr-prose a code {
	color: #111827;
}
.gr-prose pre {
	color: #e5e7eb;
	background-color: #1f2937;
	overflow-x: auto;
	font-size: 0.875em;
	line-height: 1.7142857;
	margin-top: 1.7142857em;
	margin-bottom: 1.7142857em;
	border-radius: 0.375rem;
	padding-top: 0.8571429em;
	padding-right: 1.1428571em;
	padding-bottom: 0.8571429em;
	padding-left: 1.1428571em;
}
.gr-prose pre code {
	background-color: transparent;
	border-width: 0;
	border-radius: 0;
	padding: 0;
	font-weight: 400;
	color: inherit;
	font-size: inherit;
	font-family: inherit;
	line-height: inherit;
}
.gr-prose pre code::before {
	content: none;
}
.gr-prose pre code::after {
	content: none;
}
.gr-prose table {
	width: 100%;
	table-layout: auto;
	text-align: left;
	margin-top: 2em;
	margin-bottom: 2em;
	font-size: 0.875em;
	line-height: 1.7142857;
}
.gr-prose thead {
	color: #111827;
	font-weight: 600;
	border-bottom-width: 1px;
	border-bottom-color: #d1d5db;
}
.gr-prose thead th {
	vertical-align: bottom;
	padding-right: 0.5714286em;
	padding-bottom: 0.5714286em;
	padding-left: 0.5714286em;
}
.gr-prose tbody tr {
	border-bottom-width: 1px;
	border-bottom-color: #e5e7eb;
}
.gr-prose tbody tr:last-child {
	border-bottom-width: 0;
}
.gr-prose tbody td {
	vertical-align: top;
	padding-top: 0.5714286em;
	padding-right: 0.5714286em;
	padding-bottom: 0.5714286em;
	padding-left: 0.5714286em;
}
.gr-prose {
	font-size: 1rem;
	line-height: 1.75;
}
.gr-prose p {
	margin-top: 1.25em;
	margin-bottom: 1.25em;
}
.gr-prose img {
	margin-top: 2em;
	margin-bottom: 2em;
}
.gr-prose video {
	margin-top: 2em;
	margin-bottom: 2em;
}
.gr-prose figure {
	margin-top: 2em;
	margin-bottom: 2em;
}
.gr-prose figure > * {
	margin-top: 0;
	margin-bottom: 0;
}
.gr-prose h2 code {
	font-size: 0.875em;
}
.gr-prose h3 code {
	font-size: 0.9em;
}
.gr-prose ol {
	margin-top: 1.25em;
	margin-bottom: 1.25em;
}
.gr-prose ul {
	margin-top: 1.25em;
	margin-bottom: 1.25em;
}
.gr-prose li {
	margin-top: 0.5em;
	margin-bottom: 0.5em;
}
.gr-prose > ul > li p {
	margin-top: 0.75em;
	margin-bottom: 0.75em;
}
.gr-prose > ul > li > :first-child {
	margin-top: 1.25em;
}
.gr-prose > ul > li > :last-child {
	margin-bottom: 1.25em;
}
.gr-prose > ol > li > :first-child {
	margin-top: 1.25em;
}
.gr-prose > ol > li > :last-child {
	margin-bottom: 1.25em;
}
.gr-prose ol ol,
.gr-prose ol ul,
.gr-prose ul ol,
.gr-prose ul ul {
	margin-top: 0.75em;
	margin-bottom: 0.75em;
}
.gr-prose hr + * {
	margin-top: 0;
}
.gr-prose h2 + * {
	margin-top: 0;
}
.gr-prose h3 + * {
	margin-top: 0;
}
.gr-prose h4 + * {
	margin-top: 0;
}
.gr-prose thead th:first-child {
	padding-left: 0;
}
.gr-prose thead th:last-child {
	padding-right: 0;
}
.gr-prose tbody td:first-child {
	padding-left: 0;
}
.gr-prose tbody td:last-child {
	padding-right: 0;
}
.gr-prose > :first-child {
	margin-top: 0;
}
.gr-prose > :last-child {
	margin-bottom: 0;
}
.gr-prose-sm {
	font-size: 0.875rem;
	line-height: 1.7142857;
}
.gr-prose-sm p {
	margin-top: 1.1428571em;
	margin-bottom: 1.1428571em;
}
.gr-prose-sm [class~="lead"] {
	font-size: 1.2857143em;
	line-height: 1.5555556;
	margin-top: 0.8888889em;
	margin-bottom: 0.8888889em;
}
.gr-prose-sm blockquote {
	margin-top: 1.3333333em;
	margin-bottom: 1.3333333em;
	padding-left: 1.1111111em;
}
.gr-prose-sm h1 {
	font-size: 2.1428571em;
	margin-top: 0;
	margin-bottom: 0.8em;
	line-height: 1.2;
}
.gr-prose-sm h2 {
	font-size: 1.4285714em;
	margin-top: 1.6em;
	margin-bottom: 0.8em;
	line-height: 1.4;
}
.gr-prose-sm h3 {
	font-size: 1.2857143em;
	margin-top: 1.5555556em;
	margin-bottom: 0.4444444em;
	line-height: 1.5555556;
}
.gr-prose-sm h4 {
	margin-top: 1.4285714em;
	margin-bottom: 0.5714286em;
	line-height: 1.4285714;
}
.gr-prose-sm img {
	margin-top: 1.7142857em;
	margin-bottom: 1.7142857em;
}
.gr-prose-sm video {
	margin-top: 1.7142857em;
	margin-bottom: 1.7142857em;
}
.gr-prose-sm figure {
	margin-top: 1.7142857em;
	margin-bottom: 1.7142857em;
}
.gr-prose-sm figure > * {
	margin-top: 0;
	margin-bottom: 0;
}
.gr-prose-sm figure figcaption {
	font-size: 0.8571429em;
	line-height: 1.3333333;
	margin-top: 0.6666667em;
}
.gr-prose-sm code {
	font-size: 0.8571429em;
}
.gr-prose-sm h2 code {
	font-size: 0.9em;
}
.gr-prose-sm h3 code {
	font-size: 0.8888889em;
}
.gr-prose-sm pre {
	font-size: 0.8571429em;
	line-height: 1.6666667;
	margin-top: 1.6666667em;
	margin-bottom: 1.6666667em;
	border-radius: 0.25rem;
	padding-top: 0.6666667em;
	padding-right: 1em;
	padding-bottom: 0.6666667em;
	padding-left: 1em;
}
.gr-prose-sm ol {
	margin-top: 1.1428571em;
	margin-bottom: 1.1428571em;
}
.gr-prose-sm ul {
	margin-top: 1.1428571em;
	margin-bottom: 1.1428571em;
}
.gr-prose-sm li {
	margin-top: 0.2857143em;
	margin-bottom: 0.2857143em;
}
.gr-prose-sm ol > li {
	padding-left: 1.5714286em;
}
.gr-prose-sm ol > li::before {
	left: 0;
}
.gr-prose-sm ul > li {
	padding-left: 1.5714286em;
}
.gr-prose-sm ul > li::before {
	height: 0.3571429em;
	width: 0.3571429em;
	top: calc(0.8571429em - 0.1785714em);
	left: 0.2142857em;
}
.gr-prose-sm > ul > li p {
	margin-top: 0.5714286em;
	margin-bottom: 0.5714286em;
}
.gr-prose-sm > ul > li > :first-child {
	margin-top: 1.1428571em;
}
.gr-prose-sm > ul > li > :last-child {
	margin-bottom: 1.1428571em;
}
.gr-prose-sm > ol > li > :first-child {
	margin-top: 1.1428571em;
}
.gr-prose-sm > ol > li > :last-child {
	margin-bottom: 1.1428571em;
}
.gr-prose-sm ol ol,
.gr-prose-sm ol ul,
.gr-prose-sm ul ol,
.gr-prose-sm ul ul {
	margin-top: 0.5714286em;
	margin-bottom: 0.5714286em;
}
.gr-prose-sm hr {
	margin-top: 2.8571429em;
	margin-bottom: 2.8571429em;
}
.gr-prose-sm hr + * {
	margin-top: 0;
}
.gr-prose-sm h2 + * {
	margin-top: 0;
}
.gr-prose-sm h3 + * {
	margin-top: 0;
}
.gr-prose-sm h4 + * {
	margin-top: 0;
}
.gr-prose-sm table {
	font-size: 0.8571429em;
	line-height: 1.5;
}
.gr-prose-sm thead th {
	padding-right: 1em;
	padding-bottom: 0.6666667em;
	padding-left: 1em;
}
.gr-prose-sm thead th:first-child {
	padding-left: 0;
}
.gr-prose-sm thead th:last-child {
	padding-right: 0;
}
.gr-prose-sm tbody td {
	padding-top: 0.6666667em;
	padding-right: 1em;
	padding-bottom: 0.6666667em;
	padding-left: 1em;
}
.gr-prose-sm tbody td:first-child {
	padding-left: 0;
}
.gr-prose-sm tbody td:last-child {
	padding-right: 0;
}
.gr-prose-sm > :first-child {
	margin-top: 0;
}
.gr-prose-sm > :last-child {
	margin-bottom: 0;
}
.gr-prose-lg {
	font-size: 1.125rem;
	line-height: 1.7777778;
}
.gr-prose-lg p {
	margin-top: 1.3333333em;
	margin-bottom: 1.3333333em;
}
.gr-prose-lg [class~="lead"] {
	font-size: 1.2222222em;
	line-height: 1.4545455;
	margin-top: 1.0909091em;
	margin-bottom: 1.0909091em;
}
.gr-prose-lg blockquote {
	margin-top: 1.6666667em;
	margin-bottom: 1.6666667em;
	padding-left: 1em;
}
.gr-prose-lg h1 {
	font-size: 2.6666667em;
	margin-top: 0;
	margin-bottom: 0.8333333em;
	line-height: 1;
}
.gr-prose-lg h2 {
	font-size: 1.6666667em;
	margin-top: 1.8666667em;
	margin-bottom: 1.0666667em;
	line-height: 1.3333333;
}
.gr-prose-lg h3 {
	font-size: 1.3333333em;
	margin-top: 1.6666667em;
	margin-bottom: 0.6666667em;
	line-height: 1.5;
}
.gr-prose-lg h4 {
	margin-top: 1.7777778em;
	margin-bottom: 0.4444444em;
	line-height: 1.5555556;
}
.gr-prose-lg img {
	margin-top: 1.7777778em;
	margin-bottom: 1.7777778em;
}
.gr-prose-lg video {
	margin-top: 1.7777778em;
	margin-bottom: 1.7777778em;
}
.gr-prose-lg figure {
	margin-top: 1.7777778em;
	margin-bottom: 1.7777778em;
}
.gr-prose-lg figure > * {
	margin-top: 0;
	margin-bottom: 0;
}
.gr-prose-lg figure figcaption {
	font-size: 0.8888889em;
	line-height: 1.5;
	margin-top: 1em;
}
.gr-prose-lg code {
	font-size: 0.8888889em;
}
.gr-prose-lg h2 code {
	font-size: 0.8666667em;
}
.gr-prose-lg h3 code {
	font-size: 0.875em;
}
.gr-prose-lg pre {
	font-size: 0.8888889em;
	line-height: 1.75;
	margin-top: 2em;
	margin-bottom: 2em;
	border-radius: 0.375rem;
	padding-top: 1em;
	padding-right: 1.5em;
	padding-bottom: 1em;
	padding-left: 1.5em;
}
.gr-prose-lg ol {
	margin-top: 1.3333333em;
	margin-bottom: 1.3333333em;
}
.gr-prose-lg ul {
	margin-top: 1.3333333em;
	margin-bottom: 1.3333333em;
}
.gr-prose-lg li {
	margin-top: 0.6666667em;
	margin-bottom: 0.6666667em;
}
.gr-prose-lg ol > li {
	padding-left: 1.6666667em;
}
.gr-prose-lg ol > li::before {
	left: 0;
}
.gr-prose-lg ul > li {
	padding-left: 1.6666667em;
}
.gr-prose-lg ul > li::before {
	width: 0.3333333em;
	height: 0.3333333em;
	top: calc(0.8888889em - 0.1666667em);
	left: 0.2222222em;
}
.gr-prose-lg > ul > li p {
	margin-top: 0.8888889em;
	margin-bottom: 0.8888889em;
}
.gr-prose-lg > ul > li > :first-child {
	margin-top: 1.3333333em;
}
.gr-prose-lg > ul > li > :last-child {
	margin-bottom: 1.3333333em;
}
.gr-prose-lg > ol > li > :first-child {
	margin-top: 1.3333333em;
}
.gr-prose-lg > ol > li > :last-child {
	margin-bottom: 1.3333333em;
}
.gr-prose-lg ol ol,
.gr-prose-lg ol ul,
.gr-prose-lg ul ol,
.gr-prose-lg ul ul {
	margin-top: 0.8888889em;
	margin-bottom: 0.8888889em;
}
.gr-prose-lg hr {
	margin-top: 3.1111111em;
	margin-bottom: 3.1111111em;
}
.gr-prose-lg hr + * {
	margin-top: 0;
}
.gr-prose-lg h2 + * {
	margin-top: 0;
}
.gr-prose-lg h3 + * {
	margin-top: 0;
}
.gr-prose-lg h4 + * {
	margin-top: 0;
}
.gr-prose-lg table {
	font-size: 0.8888889em;
	line-height: 1.5;
}
.gr-prose-lg thead th {
	padding-right: 0.75em;
	padding-bottom: 0.75em;
	padding-left: 0.75em;
}
.gr-prose-lg thead th:first-child {
	padding-left: 0;
}
.gr-prose-lg thead th:last-child {
	padding-right: 0;
}
.gr-prose-lg tbody td {
	padding-top: 0.75em;
	padding-right: 0.75em;
	padding-bottom: 0.75em;
	padding-left: 0.75em;
}
.gr-prose-lg tbody td:first-child {
	padding-left: 0;
}
.gr-prose-lg tbody td:last-child {
	padding-right: 0;
}
.gr-prose-lg > :first-child {
	margin-top: 0;
}
.gr-prose-lg > :last-child {
	margin-bottom: 0;
}
.gr-prose-xl {
	font-size: 1.25rem;
	line-height: 1.8;
}
.gr-prose-xl p {
	margin-top: 1.2em;
	margin-bottom: 1.2em;
}
.gr-prose-xl [class~="lead"] {
	font-size: 1.2em;
	line-height: 1.5;
	margin-top: 1em;
	margin-bottom: 1em;
}
.gr-prose-xl blockquote {
	margin-top: 1.6em;
	margin-bottom: 1.6em;
	padding-left: 1.0666667em;
}
.gr-prose-xl h1 {
	font-size: 2.8em;
	margin-top: 0;
	margin-bottom: 0.8571429em;
	line-height: 1;
}
.gr-prose-xl h2 {
	font-size: 1.8em;
	margin-top: 1.5555556em;
	margin-bottom: 0.8888889em;
	line-height: 1.1111111;
}
.gr-prose-xl h3 {
	font-size: 1.5em;
	margin-top: 1.6em;
	margin-bottom: 0.6666667em;
	line-height: 1.3333333;
}
.gr-prose-xl h4 {
	margin-top: 1.8em;
	margin-bottom: 0.6em;
	line-height: 1.6;
}
.gr-prose-xl img {
	margin-top: 2em;
	margin-bottom: 2em;
}
.gr-prose-xl video {
	margin-top: 2em;
	margin-bottom: 2em;
}
.gr-prose-xl figure {
	margin-top: 2em;
	margin-bottom: 2em;
}
.gr-prose-xl figure > * {
	margin-top: 0;
	margin-bottom: 0;
}
.gr-prose-xl figure figcaption {
	font-size: 0.9em;
	line-height: 1.5555556;
	margin-top: 1em;
}
.gr-prose-xl code {
	font-size: 0.9em;
}
.gr-prose-xl h2 code {
	font-size: 0.8611111em;
}
.gr-prose-xl h3 code {
	font-size: 0.9em;
}
.gr-prose-xl pre {
	font-size: 0.9em;
	line-height: 1.7777778;
	margin-top: 2em;
	margin-bottom: 2em;
	border-radius: 0.5rem;
	padding-top: 1.1111111em;
	padding-right: 1.3333333em;
	padding-bottom: 1.1111111em;
	padding-left: 1.3333333em;
}
.gr-prose-xl ol {
	margin-top: 1.2em;
	margin-bottom: 1.2em;
}
.gr-prose-xl ul {
	margin-top: 1.2em;
	margin-bottom: 1.2em;
}
.gr-prose-xl li {
	margin-top: 0.6em;
	margin-bottom: 0.6em;
}
.gr-prose-xl ol > li {
	padding-left: 1.8em;
}
.gr-prose-xl ol > li::before {
	left: 0;
}
.gr-prose-xl ul > li {
	padding-left: 1.8em;
}
.gr-prose-xl ul > li::before {
	width: 0.35em;
	height: 0.35em;
	top: calc(0.9em - 0.175em);
	left: 0.25em;
}
.gr-prose-xl > ul > li p {
	margin-top: 0.8em;
	margin-bottom: 0.8em;
}
.gr-prose-xl > ul > li > :first-child {
	margin-top: 1.2em;
}
.gr-prose-xl > ul > li > :last-child {
	margin-bottom: 1.2em;
}
.gr-prose-xl > ol > li > :first-child {
	margin-top: 1.2em;
}
.gr-prose-xl > ol > li > :last-child {
	margin-bottom: 1.2em;
}
.gr-prose-xl ol ol,
.gr-prose-xl ol ul,
.gr-prose-xl ul ol,
.gr-prose-xl ul ul {
	margin-top: 0.8em;
	margin-bottom: 0.8em;
}
.gr-prose-xl hr {
	margin-top: 2.8em;
	margin-bottom: 2.8em;
}
.gr-prose-xl hr + * {
	margin-top: 0;
}
.gr-prose-xl h2 + * {
	margin-top: 0;
}
.gr-prose-xl h3 + * {
	margin-top: 0;
}
.gr-prose-xl h4 + * {
	margin-top: 0;
}
.gr-prose-xl table {
	font-size: 0.9em;
	line-height: 1.5555556;
}
.gr-prose-xl thead th {
	padding-right: 0.6666667em;
	padding-bottom: 0.8888889em;
	padding-left: 0.6666667em;
}
.gr-prose-xl thead th:first-child {
	padding-left: 0;
}
.gr-prose-xl thead th:last-child {
	padding-right: 0;
}
.gr-prose-xl tbody td {
	padding-top: 0.8888889em;
	padding-right: 0.6666667em;
	padding-bottom: 0.8888889em;
	padding-left: 0.6666667em;
}
.gr-prose-xl tbody td:first-child {
	padding-left: 0;
}
.gr-prose-xl tbody td:last-child {
	padding-right: 0;
}
.gr-prose-xl > :first-child {
	margin-top: 0;
}
.gr-prose-xl > :last-child {
	margin-bottom: 0;
}
.gr-prose-2xl {
	font-size: 1.5rem;
	line-height: 1.6666667;
}
.gr-prose-2xl p {
	margin-top: 1.3333333em;
	margin-bottom: 1.3333333em;
}
.gr-prose-2xl [class~="lead"] {
	font-size: 1.25em;
	line-height: 1.4666667;
	margin-top: 1.0666667em;
	margin-bottom: 1.0666667em;
}
.gr-prose-2xl blockquote {
	margin-top: 1.7777778em;
	margin-bottom: 1.7777778em;
	padding-left: 1.1111111em;
}
.gr-prose-2xl h1 {
	font-size: 2.6666667em;
	margin-top: 0;
	margin-bottom: 0.875em;
	line-height: 1;
}
.gr-prose-2xl h2 {
	font-size: 2em;
	margin-top: 1.5em;
	margin-bottom: 0.8333333em;
	line-height: 1.0833333;
}
.gr-prose-2xl h3 {
	font-size: 1.5em;
	margin-top: 1.5555556em;
	margin-bottom: 0.6666667em;
	line-height: 1.2222222;
}
.gr-prose-2xl h4 {
	margin-top: 1.6666667em;
	margin-bottom: 0.6666667em;
	line-height: 1.5;
}
.gr-prose-2xl img {
	margin-top: 2em;
	margin-bottom: 2em;
}
.gr-prose-2xl video {
	margin-top: 2em;
	margin-bottom: 2em;
}
.gr-prose-2xl figure {
	margin-top: 2em;
	margin-bottom: 2em;
}
.gr-prose-2xl figure > * {
	margin-top: 0;
	margin-bottom: 0;
}
.gr-prose-2xl figure figcaption {
	font-size: 0.8333333em;
	line-height: 1.6;
	margin-top: 1em;
}
.gr-prose-2xl code {
	font-size: 0.8333333em;
}
.gr-prose-2xl h2 code {
	font-size: 0.875em;
}
.gr-prose-2xl h3 code {
	font-size: 0.8888889em;
}
.gr-prose-2xl pre {
	font-size: 0.8333333em;
	line-height: 1.8;
	margin-top: 2em;
	margin-bottom: 2em;
	border-radius: 0.5rem;
	padding-top: 1.2em;
	padding-right: 1.6em;
	padding-bottom: 1.2em;
	padding-left: 1.6em;
}
.gr-prose-2xl ol {
	margin-top: 1.3333333em;
	margin-bottom: 1.3333333em;
}
.gr-prose-2xl ul {
	margin-top: 1.3333333em;
	margin-bottom: 1.3333333em;
}
.gr-prose-2xl li {
	margin-top: 0.5em;
	margin-bottom: 0.5em;
}
.gr-prose-2xl ol > li {
	padding-left: 1.6666667em;
}
.gr-prose-2xl ol > li::before {
	left: 0;
}
.gr-prose-2xl ul > li {
	padding-left: 1.6666667em;
}
.gr-prose-2xl ul > li::before {
	width: 0.3333333em;
	height: 0.3333333em;
	top: calc(0.8333333em - 0.1666667em);
	left: 0.25em;
}
.gr-prose-2xl > ul > li p {
	margin-top: 0.8333333em;
	margin-bottom: 0.8333333em;
}
.gr-prose-2xl > ul > li > :first-child {
	margin-top: 1.3333333em;
}
.gr-prose-2xl > ul > li > :last-child {
	margin-bottom: 1.3333333em;
}
.gr-prose-2xl > ol > li > :first-child {
	margin-top: 1.3333333em;
}
.gr-prose-2xl > ol > li > :last-child {
	margin-bottom: 1.3333333em;
}
.gr-prose-2xl ol ol,
.gr-prose-2xl ol ul,
.gr-prose-2xl ul ol,
.gr-prose-2xl ul ul {
	margin-top: 0.6666667em;
	margin-bottom: 0.6666667em;
}
.gr-prose-2xl hr {
	margin-top: 3em;
	margin-bottom: 3em;
}
.gr-prose-2xl hr + * {
	margin-top: 0;
}
.gr-prose-2xl h2 + * {
	margin-top: 0;
}
.gr-prose-2xl h3 + * {
	margin-top: 0;
}
.gr-prose-2xl h4 + * {
	margin-top: 0;
}
.gr-prose-2xl table {
	font-size: 0.8333333em;
	line-height: 1.4;
}
.gr-prose-2xl thead th {
	padding-right: 0.6em;
	padding-bottom: 0.8em;
	padding-left: 0.6em;
}
.gr-prose-2xl thead th:first-child {
	padding-left: 0;
}
.gr-prose-2xl thead th:last-child {
	padding-right: 0;
}
.gr-prose-2xl tbody td {
	padding-top: 0.8em;
	padding-right: 0.6em;
	padding-bottom: 0.8em;
	padding-left: 0.6em;
}
.gr-prose-2xl tbody td:first-child {
	padding-left: 0;
}
.gr-prose-2xl tbody td:last-child {
	padding-right: 0;
}
.gr-prose-2xl > :first-child {
	margin-top: 0;
}
.gr-prose-2xl > :last-child {
	margin-bottom: 0;
}
.gr-prose-red a {
	color: #dc2626;
}
.gr-prose-red a code {
	color: #dc2626;
}
.gr-prose-yellow a {
	color: #d97706;
}
.gr-prose-yellow a code {
	color: #d97706;
}
.gr-prose-green a {
	color: #059669;
}
.gr-prose-green a code {
	color: #059669;
}
.gr-prose-blue a {
	color: #2563eb;
}
.gr-prose-blue a code {
	color: #2563eb;
}
.gr-prose-indigo a {
	color: #4f46e5;
}
.gr-prose-indigo a code {
	color: #4f46e5;
}
.gr-prose-purple a {
	color: #7c3aed;
}
.gr-prose-purple a code {
	color: #7c3aed;
}
.gr-prose-pink a {
	color: #db2777;
}
.gr-prose-pink a code {
	color: #db2777;
}
.dark .gr-prose {
	color: #daddd8;
}
.dark .gr-prose a {
	color: #ffffff;
}
.dark .gr-prose strong {
	color: #daddd8;
}
.dark .gr-prose code {
	color: #daddd8;
}
.dark :is(h1, h2, h3, h4) {
	color: #ffffff;
}
@media (min-width: 640px) {
	.sm\:gr-prose {
		color: #374151;
		max-width: 65ch;
	}
	.sm\:gr-prose [class~="lead"] {
		color: #4b5563;
		font-size: 1.25em;
		line-height: 1.6;
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.sm\:gr-prose a {
		color: #111827;
		text-decoration: underline;
		font-weight: 500;
	}
	.sm\:gr-prose strong {
		color: #111827;
		font-weight: 600;
	}
	.sm\:gr-prose ol[type="A"] {
		--list-counter-style: upper-alpha;
	}
	.sm\:gr-prose ol[type="a"] {
		--list-counter-style: lower-alpha;
	}
	.sm\:gr-prose ol[type="A"s] {
		--list-counter-style: upper-alpha;
	}
	.sm\:gr-prose ol[type="a"s] {
		--list-counter-style: lower-alpha;
	}
	.sm\:gr-prose ol[type="I"] {
		--list-counter-style: upper-roman;
	}
	.sm\:gr-prose ol[type="i"] {
		--list-counter-style: lower-roman;
	}
	.sm\:gr-prose ol[type="I"s] {
		--list-counter-style: upper-roman;
	}
	.sm\:gr-prose ol[type="i"s] {
		--list-counter-style: lower-roman;
	}
	.sm\:gr-prose ol[type="1"] {
		--list-counter-style: decimal;
	}
	.sm\:gr-prose ol > li {
		position: relative;
		padding-left: 1.75em;
	}
	.sm\:gr-prose ol > li::before {
		content: counter(list-item, var(--list-counter-style, decimal)) ".";
		position: absolute;
		font-weight: 400;
		color: #6b7280;
		left: 0;
	}
	.sm\:gr-prose ul > li {
		position: relative;
		padding-left: 1.75em;
	}
	.sm\:gr-prose ul > li::before {
		content: "";
		position: absolute;
		background-color: #d1d5db;
		border-radius: 50%;
		width: 0.375em;
		height: 0.375em;
		top: calc(0.875em - 0.1875em);
		left: 0.25em;
	}
	.sm\:gr-prose hr {
		border-color: #e5e7eb;
		border-top-width: 1px;
		margin-top: 3em;
		margin-bottom: 3em;
	}
	.sm\:gr-prose blockquote {
		font-weight: 500;
		font-style: italic;
		color: #111827;
		border-left-width: 0.25rem;
		border-left-color: #e5e7eb;
		quotes: "\201C""\201D""\2018""\2019";
		margin-top: 1.6em;
		margin-bottom: 1.6em;
		padding-left: 1em;
	}
	.sm\:gr-prose blockquote p:first-of-type::before {
		content: open-quote;
	}
	.sm\:gr-prose blockquote p:last-of-type::after {
		content: close-quote;
	}
	.sm\:gr-prose h1 {
		color: #111827;
		font-weight: 600;
		font-size: 2.25em;
		margin-top: 0;
		margin-bottom: 0.8888889em;
		line-height: 1.1111111;
	}
	.sm\:gr-prose h2 {
		color: #111827;
		font-weight: 600;
		font-size: 1.5em;
		margin-top: 2em;
		margin-bottom: 1em;
		line-height: 1.3333333;
	}
	.sm\:gr-prose h3 {
		color: #111827;
		font-weight: 600;
		font-size: 1.25em;
		margin-top: 1.6em;
		margin-bottom: 0.6em;
		line-height: 1.6;
	}
	.sm\:gr-prose h4 {
		color: #111827;
		font-weight: 600;
		margin-top: 1.5em;
		margin-bottom: 0.5em;
		line-height: 1.5;
	}
	.sm\:gr-prose figure figcaption {
		color: #6b7280;
		font-size: 0.875em;
		line-height: 1.4285714;
		margin-top: 0.8571429em;
	}
	.sm\:gr-prose code {
		color: #111827;
		font-weight: 600;
		font-size: 0.875em;
	}
	.sm\:gr-prose code::before {
		content: "`";
	}
	.sm\:gr-prose code::after {
		content: "`";
	}
	.sm\:gr-prose a code {
		color: #111827;
	}
	.sm\:gr-prose pre {
		color: #e5e7eb;
		background-color: #1f2937;
		overflow-x: auto;
		font-size: 0.875em;
		line-height: 1.7142857;
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
		border-radius: 0.375rem;
		padding-top: 0.8571429em;
		padding-right: 1.1428571em;
		padding-bottom: 0.8571429em;
		padding-left: 1.1428571em;
	}
	.sm\:gr-prose pre code {
		background-color: transparent;
		border-width: 0;
		border-radius: 0;
		padding: 0;
		font-weight: 400;
		color: inherit;
		font-size: inherit;
		font-family: inherit;
		line-height: inherit;
	}
	.sm\:gr-prose pre code::before {
		content: none;
	}
	.sm\:gr-prose pre code::after {
		content: none;
	}
	.sm\:gr-prose table {
		width: 100%;
		table-layout: auto;
		text-align: left;
		margin-top: 2em;
		margin-bottom: 2em;
		font-size: 0.875em;
		line-height: 1.7142857;
	}
	.sm\:gr-prose thead {
		color: #111827;
		font-weight: 600;
		border-bottom-width: 1px;
		border-bottom-color: #d1d5db;
	}
	.sm\:gr-prose thead th {
		vertical-align: bottom;
		padding-right: 0.5714286em;
		padding-bottom: 0.5714286em;
		padding-left: 0.5714286em;
	}
	.sm\:gr-prose tbody tr {
		border-bottom-width: 1px;
		border-bottom-color: #e5e7eb;
	}
	.sm\:gr-prose tbody tr:last-child {
		border-bottom-width: 0;
	}
	.sm\:gr-prose tbody td {
		vertical-align: top;
		padding-top: 0.5714286em;
		padding-right: 0.5714286em;
		padding-bottom: 0.5714286em;
		padding-left: 0.5714286em;
	}
	.sm\:gr-prose {
		font-size: 1rem;
		line-height: 1.75;
	}
	.sm\:gr-prose p {
		margin-top: 1.25em;
		margin-bottom: 1.25em;
	}
	.sm\:gr-prose img {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.sm\:gr-prose video {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.sm\:gr-prose figure {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.sm\:gr-prose figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.sm\:gr-prose h2 code {
		font-size: 0.875em;
	}
	.sm\:gr-prose h3 code {
		font-size: 0.9em;
	}
	.sm\:gr-prose ol {
		margin-top: 1.25em;
		margin-bottom: 1.25em;
	}
	.sm\:gr-prose ul {
		margin-top: 1.25em;
		margin-bottom: 1.25em;
	}
	.sm\:gr-prose li {
		margin-top: 0.5em;
		margin-bottom: 0.5em;
	}
	.sm\:gr-prose > ul > li p {
		margin-top: 0.75em;
		margin-bottom: 0.75em;
	}
	.sm\:gr-prose > ul > li > :first-child {
		margin-top: 1.25em;
	}
	.sm\:gr-prose > ul > li > :last-child {
		margin-bottom: 1.25em;
	}
	.sm\:gr-prose > ol > li > :first-child {
		margin-top: 1.25em;
	}
	.sm\:gr-prose > ol > li > :last-child {
		margin-bottom: 1.25em;
	}
	.sm\:gr-prose ol ol,
	.sm\:gr-prose ol ul,
	.sm\:gr-prose ul ol,
	.sm\:gr-prose ul ul {
		margin-top: 0.75em;
		margin-bottom: 0.75em;
	}
	.sm\:gr-prose hr + * {
		margin-top: 0;
	}
	.sm\:gr-prose h2 + * {
		margin-top: 0;
	}
	.sm\:gr-prose h3 + * {
		margin-top: 0;
	}
	.sm\:gr-prose h4 + * {
		margin-top: 0;
	}
	.sm\:gr-prose thead th:first-child {
		padding-left: 0;
	}
	.sm\:gr-prose thead th:last-child {
		padding-right: 0;
	}
	.sm\:gr-prose tbody td:first-child {
		padding-left: 0;
	}
	.sm\:gr-prose tbody td:last-child {
		padding-right: 0;
	}
	.sm\:gr-prose > :first-child {
		margin-top: 0;
	}
	.sm\:gr-prose > :last-child {
		margin-bottom: 0;
	}
	.sm\:gr-prose-sm {
		font-size: 0.875rem;
		line-height: 1.7142857;
	}
	.sm\:gr-prose-sm p {
		margin-top: 1.1428571em;
		margin-bottom: 1.1428571em;
	}
	.sm\:gr-prose-sm [class~="lead"] {
		font-size: 1.2857143em;
		line-height: 1.5555556;
		margin-top: 0.8888889em;
		margin-bottom: 0.8888889em;
	}
	.sm\:gr-prose-sm blockquote {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
		padding-left: 1.1111111em;
	}
	.sm\:gr-prose-sm h1 {
		font-size: 2.1428571em;
		margin-top: 0;
		margin-bottom: 0.8em;
		line-height: 1.2;
	}
	.sm\:gr-prose-sm h2 {
		font-size: 1.4285714em;
		margin-top: 1.6em;
		margin-bottom: 0.8em;
		line-height: 1.4;
	}
	.sm\:gr-prose-sm h3 {
		font-size: 1.2857143em;
		margin-top: 1.5555556em;
		margin-bottom: 0.4444444em;
		line-height: 1.5555556;
	}
	.sm\:gr-prose-sm h4 {
		margin-top: 1.4285714em;
		margin-bottom: 0.5714286em;
		line-height: 1.4285714;
	}
	.sm\:gr-prose-sm img {
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
	}
	.sm\:gr-prose-sm video {
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
	}
	.sm\:gr-prose-sm figure {
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
	}
	.sm\:gr-prose-sm figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.sm\:gr-prose-sm figure figcaption {
		font-size: 0.8571429em;
		line-height: 1.3333333;
		margin-top: 0.6666667em;
	}
	.sm\:gr-prose-sm code {
		font-size: 0.8571429em;
	}
	.sm\:gr-prose-sm h2 code {
		font-size: 0.9em;
	}
	.sm\:gr-prose-sm h3 code {
		font-size: 0.8888889em;
	}
	.sm\:gr-prose-sm pre {
		font-size: 0.8571429em;
		line-height: 1.6666667;
		margin-top: 1.6666667em;
		margin-bottom: 1.6666667em;
		border-radius: 0.25rem;
		padding-top: 0.6666667em;
		padding-right: 1em;
		padding-bottom: 0.6666667em;
		padding-left: 1em;
	}
	.sm\:gr-prose-sm ol {
		margin-top: 1.1428571em;
		margin-bottom: 1.1428571em;
	}
	.sm\:gr-prose-sm ul {
		margin-top: 1.1428571em;
		margin-bottom: 1.1428571em;
	}
	.sm\:gr-prose-sm li {
		margin-top: 0.2857143em;
		margin-bottom: 0.2857143em;
	}
	.sm\:gr-prose-sm ol > li {
		padding-left: 1.5714286em;
	}
	.sm\:gr-prose-sm ol > li::before {
		left: 0;
	}
	.sm\:gr-prose-sm ul > li {
		padding-left: 1.5714286em;
	}
	.sm\:gr-prose-sm ul > li::before {
		height: 0.3571429em;
		width: 0.3571429em;
		top: calc(0.8571429em - 0.1785714em);
		left: 0.2142857em;
	}
	.sm\:gr-prose-sm > ul > li p {
		margin-top: 0.5714286em;
		margin-bottom: 0.5714286em;
	}
	.sm\:gr-prose-sm > ul > li > :first-child {
		margin-top: 1.1428571em;
	}
	.sm\:gr-prose-sm > ul > li > :last-child {
		margin-bottom: 1.1428571em;
	}
	.sm\:gr-prose-sm > ol > li > :first-child {
		margin-top: 1.1428571em;
	}
	.sm\:gr-prose-sm > ol > li > :last-child {
		margin-bottom: 1.1428571em;
	}
	.sm\:gr-prose-sm ol ol,
	.sm\:gr-prose-sm ol ul,
	.sm\:gr-prose-sm ul ol,
	.sm\:gr-prose-sm ul ul {
		margin-top: 0.5714286em;
		margin-bottom: 0.5714286em;
	}
	.sm\:gr-prose-sm hr {
		margin-top: 2.8571429em;
		margin-bottom: 2.8571429em;
	}
	.sm\:gr-prose-sm hr + * {
		margin-top: 0;
	}
	.sm\:gr-prose-sm h2 + * {
		margin-top: 0;
	}
	.sm\:gr-prose-sm h3 + * {
		margin-top: 0;
	}
	.sm\:gr-prose-sm h4 + * {
		margin-top: 0;
	}
	.sm\:gr-prose-sm table {
		font-size: 0.8571429em;
		line-height: 1.5;
	}
	.sm\:gr-prose-sm thead th {
		padding-right: 1em;
		padding-bottom: 0.6666667em;
		padding-left: 1em;
	}
	.sm\:gr-prose-sm thead th:first-child {
		padding-left: 0;
	}
	.sm\:gr-prose-sm thead th:last-child {
		padding-right: 0;
	}
	.sm\:gr-prose-sm tbody td {
		padding-top: 0.6666667em;
		padding-right: 1em;
		padding-bottom: 0.6666667em;
		padding-left: 1em;
	}
	.sm\:gr-prose-sm tbody td:first-child {
		padding-left: 0;
	}
	.sm\:gr-prose-sm tbody td:last-child {
		padding-right: 0;
	}
	.sm\:gr-prose-sm > :first-child {
		margin-top: 0;
	}
	.sm\:gr-prose-sm > :last-child {
		margin-bottom: 0;
	}
	.sm\:gr-prose-lg {
		font-size: 1.125rem;
		line-height: 1.7777778;
	}
	.sm\:gr-prose-lg p {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.sm\:gr-prose-lg [class~="lead"] {
		font-size: 1.2222222em;
		line-height: 1.4545455;
		margin-top: 1.0909091em;
		margin-bottom: 1.0909091em;
	}
	.sm\:gr-prose-lg blockquote {
		margin-top: 1.6666667em;
		margin-bottom: 1.6666667em;
		padding-left: 1em;
	}
	.sm\:gr-prose-lg h1 {
		font-size: 2.6666667em;
		margin-top: 0;
		margin-bottom: 0.8333333em;
		line-height: 1;
	}
	.sm\:gr-prose-lg h2 {
		font-size: 1.6666667em;
		margin-top: 1.8666667em;
		margin-bottom: 1.0666667em;
		line-height: 1.3333333;
	}
	.sm\:gr-prose-lg h3 {
		font-size: 1.3333333em;
		margin-top: 1.6666667em;
		margin-bottom: 0.6666667em;
		line-height: 1.5;
	}
	.sm\:gr-prose-lg h4 {
		margin-top: 1.7777778em;
		margin-bottom: 0.4444444em;
		line-height: 1.5555556;
	}
	.sm\:gr-prose-lg img {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
	}
	.sm\:gr-prose-lg video {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
	}
	.sm\:gr-prose-lg figure {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
	}
	.sm\:gr-prose-lg figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.sm\:gr-prose-lg figure figcaption {
		font-size: 0.8888889em;
		line-height: 1.5;
		margin-top: 1em;
	}
	.sm\:gr-prose-lg code {
		font-size: 0.8888889em;
	}
	.sm\:gr-prose-lg h2 code {
		font-size: 0.8666667em;
	}
	.sm\:gr-prose-lg h3 code {
		font-size: 0.875em;
	}
	.sm\:gr-prose-lg pre {
		font-size: 0.8888889em;
		line-height: 1.75;
		margin-top: 2em;
		margin-bottom: 2em;
		border-radius: 0.375rem;
		padding-top: 1em;
		padding-right: 1.5em;
		padding-bottom: 1em;
		padding-left: 1.5em;
	}
	.sm\:gr-prose-lg ol {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.sm\:gr-prose-lg ul {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.sm\:gr-prose-lg li {
		margin-top: 0.6666667em;
		margin-bottom: 0.6666667em;
	}
	.sm\:gr-prose-lg ol > li {
		padding-left: 1.6666667em;
	}
	.sm\:gr-prose-lg ol > li::before {
		left: 0;
	}
	.sm\:gr-prose-lg ul > li {
		padding-left: 1.6666667em;
	}
	.sm\:gr-prose-lg ul > li::before {
		width: 0.3333333em;
		height: 0.3333333em;
		top: calc(0.8888889em - 0.1666667em);
		left: 0.2222222em;
	}
	.sm\:gr-prose-lg > ul > li p {
		margin-top: 0.8888889em;
		margin-bottom: 0.8888889em;
	}
	.sm\:gr-prose-lg > ul > li > :first-child {
		margin-top: 1.3333333em;
	}
	.sm\:gr-prose-lg > ul > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.sm\:gr-prose-lg > ol > li > :first-child {
		margin-top: 1.3333333em;
	}
	.sm\:gr-prose-lg > ol > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.sm\:gr-prose-lg ol ol,
	.sm\:gr-prose-lg ol ul,
	.sm\:gr-prose-lg ul ol,
	.sm\:gr-prose-lg ul ul {
		margin-top: 0.8888889em;
		margin-bottom: 0.8888889em;
	}
	.sm\:gr-prose-lg hr {
		margin-top: 3.1111111em;
		margin-bottom: 3.1111111em;
	}
	.sm\:gr-prose-lg hr + * {
		margin-top: 0;
	}
	.sm\:gr-prose-lg h2 + * {
		margin-top: 0;
	}
	.sm\:gr-prose-lg h3 + * {
		margin-top: 0;
	}
	.sm\:gr-prose-lg h4 + * {
		margin-top: 0;
	}
	.sm\:gr-prose-lg table {
		font-size: 0.8888889em;
		line-height: 1.5;
	}
	.sm\:gr-prose-lg thead th {
		padding-right: 0.75em;
		padding-bottom: 0.75em;
		padding-left: 0.75em;
	}
	.sm\:gr-prose-lg thead th:first-child {
		padding-left: 0;
	}
	.sm\:gr-prose-lg thead th:last-child {
		padding-right: 0;
	}
	.sm\:gr-prose-lg tbody td {
		padding-top: 0.75em;
		padding-right: 0.75em;
		padding-bottom: 0.75em;
		padding-left: 0.75em;
	}
	.sm\:gr-prose-lg tbody td:first-child {
		padding-left: 0;
	}
	.sm\:gr-prose-lg tbody td:last-child {
		padding-right: 0;
	}
	.sm\:gr-prose-lg > :first-child {
		margin-top: 0;
	}
	.sm\:gr-prose-lg > :last-child {
		margin-bottom: 0;
	}
	.sm\:gr-prose-xl {
		font-size: 1.25rem;
		line-height: 1.8;
	}
	.sm\:gr-prose-xl p {
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.sm\:gr-prose-xl [class~="lead"] {
		font-size: 1.2em;
		line-height: 1.5;
		margin-top: 1em;
		margin-bottom: 1em;
	}
	.sm\:gr-prose-xl blockquote {
		margin-top: 1.6em;
		margin-bottom: 1.6em;
		padding-left: 1.0666667em;
	}
	.sm\:gr-prose-xl h1 {
		font-size: 2.8em;
		margin-top: 0;
		margin-bottom: 0.8571429em;
		line-height: 1;
	}
	.sm\:gr-prose-xl h2 {
		font-size: 1.8em;
		margin-top: 1.5555556em;
		margin-bottom: 0.8888889em;
		line-height: 1.1111111;
	}
	.sm\:gr-prose-xl h3 {
		font-size: 1.5em;
		margin-top: 1.6em;
		margin-bottom: 0.6666667em;
		line-height: 1.3333333;
	}
	.sm\:gr-prose-xl h4 {
		margin-top: 1.8em;
		margin-bottom: 0.6em;
		line-height: 1.6;
	}
	.sm\:gr-prose-xl img {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.sm\:gr-prose-xl video {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.sm\:gr-prose-xl figure {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.sm\:gr-prose-xl figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.sm\:gr-prose-xl figure figcaption {
		font-size: 0.9em;
		line-height: 1.5555556;
		margin-top: 1em;
	}
	.sm\:gr-prose-xl code {
		font-size: 0.9em;
	}
	.sm\:gr-prose-xl h2 code {
		font-size: 0.8611111em;
	}
	.sm\:gr-prose-xl h3 code {
		font-size: 0.9em;
	}
	.sm\:gr-prose-xl pre {
		font-size: 0.9em;
		line-height: 1.7777778;
		margin-top: 2em;
		margin-bottom: 2em;
		border-radius: 0.5rem;
		padding-top: 1.1111111em;
		padding-right: 1.3333333em;
		padding-bottom: 1.1111111em;
		padding-left: 1.3333333em;
	}
	.sm\:gr-prose-xl ol {
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.sm\:gr-prose-xl ul {
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.sm\:gr-prose-xl li {
		margin-top: 0.6em;
		margin-bottom: 0.6em;
	}
	.sm\:gr-prose-xl ol > li {
		padding-left: 1.8em;
	}
	.sm\:gr-prose-xl ol > li::before {
		left: 0;
	}
	.sm\:gr-prose-xl ul > li {
		padding-left: 1.8em;
	}
	.sm\:gr-prose-xl ul > li::before {
		width: 0.35em;
		height: 0.35em;
		top: calc(0.9em - 0.175em);
		left: 0.25em;
	}
	.sm\:gr-prose-xl > ul > li p {
		margin-top: 0.8em;
		margin-bottom: 0.8em;
	}
	.sm\:gr-prose-xl > ul > li > :first-child {
		margin-top: 1.2em;
	}
	.sm\:gr-prose-xl > ul > li > :last-child {
		margin-bottom: 1.2em;
	}
	.sm\:gr-prose-xl > ol > li > :first-child {
		margin-top: 1.2em;
	}
	.sm\:gr-prose-xl > ol > li > :last-child {
		margin-bottom: 1.2em;
	}
	.sm\:gr-prose-xl ol ol,
	.sm\:gr-prose-xl ol ul,
	.sm\:gr-prose-xl ul ol,
	.sm\:gr-prose-xl ul ul {
		margin-top: 0.8em;
		margin-bottom: 0.8em;
	}
	.sm\:gr-prose-xl hr {
		margin-top: 2.8em;
		margin-bottom: 2.8em;
	}
	.sm\:gr-prose-xl hr + * {
		margin-top: 0;
	}
	.sm\:gr-prose-xl h2 + * {
		margin-top: 0;
	}
	.sm\:gr-prose-xl h3 + * {
		margin-top: 0;
	}
	.sm\:gr-prose-xl h4 + * {
		margin-top: 0;
	}
	.sm\:gr-prose-xl table {
		font-size: 0.9em;
		line-height: 1.5555556;
	}
	.sm\:gr-prose-xl thead th {
		padding-right: 0.6666667em;
		padding-bottom: 0.8888889em;
		padding-left: 0.6666667em;
	}
	.sm\:gr-prose-xl thead th:first-child {
		padding-left: 0;
	}
	.sm\:gr-prose-xl thead th:last-child {
		padding-right: 0;
	}
	.sm\:gr-prose-xl tbody td {
		padding-top: 0.8888889em;
		padding-right: 0.6666667em;
		padding-bottom: 0.8888889em;
		padding-left: 0.6666667em;
	}
	.sm\:gr-prose-xl tbody td:first-child {
		padding-left: 0;
	}
	.sm\:gr-prose-xl tbody td:last-child {
		padding-right: 0;
	}
	.sm\:gr-prose-xl > :first-child {
		margin-top: 0;
	}
	.sm\:gr-prose-xl > :last-child {
		margin-bottom: 0;
	}
	.sm\:gr-prose-2xl {
		font-size: 1.5rem;
		line-height: 1.6666667;
	}
	.sm\:gr-prose-2xl p {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.sm\:gr-prose-2xl [class~="lead"] {
		font-size: 1.25em;
		line-height: 1.4666667;
		margin-top: 1.0666667em;
		margin-bottom: 1.0666667em;
	}
	.sm\:gr-prose-2xl blockquote {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
		padding-left: 1.1111111em;
	}
	.sm\:gr-prose-2xl h1 {
		font-size: 2.6666667em;
		margin-top: 0;
		margin-bottom: 0.875em;
		line-height: 1;
	}
	.sm\:gr-prose-2xl h2 {
		font-size: 2em;
		margin-top: 1.5em;
		margin-bottom: 0.8333333em;
		line-height: 1.0833333;
	}
	.sm\:gr-prose-2xl h3 {
		font-size: 1.5em;
		margin-top: 1.5555556em;
		margin-bottom: 0.6666667em;
		line-height: 1.2222222;
	}
	.sm\:gr-prose-2xl h4 {
		margin-top: 1.6666667em;
		margin-bottom: 0.6666667em;
		line-height: 1.5;
	}
	.sm\:gr-prose-2xl img {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.sm\:gr-prose-2xl video {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.sm\:gr-prose-2xl figure {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.sm\:gr-prose-2xl figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.sm\:gr-prose-2xl figure figcaption {
		font-size: 0.8333333em;
		line-height: 1.6;
		margin-top: 1em;
	}
	.sm\:gr-prose-2xl code {
		font-size: 0.8333333em;
	}
	.sm\:gr-prose-2xl h2 code {
		font-size: 0.875em;
	}
	.sm\:gr-prose-2xl h3 code {
		font-size: 0.8888889em;
	}
	.sm\:gr-prose-2xl pre {
		font-size: 0.8333333em;
		line-height: 1.8;
		margin-top: 2em;
		margin-bottom: 2em;
		border-radius: 0.5rem;
		padding-top: 1.2em;
		padding-right: 1.6em;
		padding-bottom: 1.2em;
		padding-left: 1.6em;
	}
	.sm\:gr-prose-2xl ol {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.sm\:gr-prose-2xl ul {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.sm\:gr-prose-2xl li {
		margin-top: 0.5em;
		margin-bottom: 0.5em;
	}
	.sm\:gr-prose-2xl ol > li {
		padding-left: 1.6666667em;
	}
	.sm\:gr-prose-2xl ol > li::before {
		left: 0;
	}
	.sm\:gr-prose-2xl ul > li {
		padding-left: 1.6666667em;
	}
	.sm\:gr-prose-2xl ul > li::before {
		width: 0.3333333em;
		height: 0.3333333em;
		top: calc(0.8333333em - 0.1666667em);
		left: 0.25em;
	}
	.sm\:gr-prose-2xl > ul > li p {
		margin-top: 0.8333333em;
		margin-bottom: 0.8333333em;
	}
	.sm\:gr-prose-2xl > ul > li > :first-child {
		margin-top: 1.3333333em;
	}
	.sm\:gr-prose-2xl > ul > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.sm\:gr-prose-2xl > ol > li > :first-child {
		margin-top: 1.3333333em;
	}
	.sm\:gr-prose-2xl > ol > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.sm\:gr-prose-2xl ol ol,
	.sm\:gr-prose-2xl ol ul,
	.sm\:gr-prose-2xl ul ol,
	.sm\:gr-prose-2xl ul ul {
		margin-top: 0.6666667em;
		margin-bottom: 0.6666667em;
	}
	.sm\:gr-prose-2xl hr {
		margin-top: 3em;
		margin-bottom: 3em;
	}
	.sm\:gr-prose-2xl hr + * {
		margin-top: 0;
	}
	.sm\:gr-prose-2xl h2 + * {
		margin-top: 0;
	}
	.sm\:gr-prose-2xl h3 + * {
		margin-top: 0;
	}
	.sm\:gr-prose-2xl h4 + * {
		margin-top: 0;
	}
	.sm\:gr-prose-2xl table {
		font-size: 0.8333333em;
		line-height: 1.4;
	}
	.sm\:gr-prose-2xl thead th {
		padding-right: 0.6em;
		padding-bottom: 0.8em;
		padding-left: 0.6em;
	}
	.sm\:gr-prose-2xl thead th:first-child {
		padding-left: 0;
	}
	.sm\:gr-prose-2xl thead th:last-child {
		padding-right: 0;
	}
	.sm\:gr-prose-2xl tbody td {
		padding-top: 0.8em;
		padding-right: 0.6em;
		padding-bottom: 0.8em;
		padding-left: 0.6em;
	}
	.sm\:gr-prose-2xl tbody td:first-child {
		padding-left: 0;
	}
	.sm\:gr-prose-2xl tbody td:last-child {
		padding-right: 0;
	}
	.sm\:gr-prose-2xl > :first-child {
		margin-top: 0;
	}
	.sm\:gr-prose-2xl > :last-child {
		margin-bottom: 0;
	}
	.sm\:gr-prose-red a {
		color: #dc2626;
	}
	.sm\:gr-prose-red a code {
		color: #dc2626;
	}
	.sm\:gr-prose-yellow a {
		color: #d97706;
	}
	.sm\:gr-prose-yellow a code {
		color: #d97706;
	}
	.sm\:gr-prose-green a {
		color: #059669;
	}
	.sm\:gr-prose-green a code {
		color: #059669;
	}
	.sm\:gr-prose-blue a {
		color: #2563eb;
	}
	.sm\:gr-prose-blue a code {
		color: #2563eb;
	}
	.sm\:gr-prose-indigo a {
		color: #4f46e5;
	}
	.sm\:gr-prose-indigo a code {
		color: #4f46e5;
	}
	.sm\:gr-prose-purple a {
		color: #7c3aed;
	}
	.sm\:gr-prose-purple a code {
		color: #7c3aed;
	}
	.sm\:gr-prose-pink a {
		color: #db2777;
	}
	.sm\:gr-prose-pink a code {
		color: #db2777;
	}
}
@media (min-width: 768px) {
	.md\:gr-prose {
		color: #374151;
		max-width: 65ch;
	}
	.md\:gr-prose [class~="lead"] {
		color: #4b5563;
		font-size: 1.25em;
		line-height: 1.6;
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.md\:gr-prose a {
		color: #111827;
		text-decoration: underline;
		font-weight: 500;
	}
	.md\:gr-prose strong {
		color: #111827;
		font-weight: 600;
	}
	.md\:gr-prose ol[type="A"] {
		--list-counter-style: upper-alpha;
	}
	.md\:gr-prose ol[type="a"] {
		--list-counter-style: lower-alpha;
	}
	.md\:gr-prose ol[type="A"s] {
		--list-counter-style: upper-alpha;
	}
	.md\:gr-prose ol[type="a"s] {
		--list-counter-style: lower-alpha;
	}
	.md\:gr-prose ol[type="I"] {
		--list-counter-style: upper-roman;
	}
	.md\:gr-prose ol[type="i"] {
		--list-counter-style: lower-roman;
	}
	.md\:gr-prose ol[type="I"s] {
		--list-counter-style: upper-roman;
	}
	.md\:gr-prose ol[type="i"s] {
		--list-counter-style: lower-roman;
	}
	.md\:gr-prose ol[type="1"] {
		--list-counter-style: decimal;
	}
	.md\:gr-prose ol > li {
		position: relative;
		padding-left: 1.75em;
	}
	.md\:gr-prose ol > li::before {
		content: counter(list-item, var(--list-counter-style, decimal)) ".";
		position: absolute;
		font-weight: 400;
		color: #6b7280;
		left: 0;
	}
	.md\:gr-prose ul > li {
		position: relative;
		padding-left: 1.75em;
	}
	.md\:gr-prose ul > li::before {
		content: "";
		position: absolute;
		background-color: #d1d5db;
		border-radius: 50%;
		width: 0.375em;
		height: 0.375em;
		top: calc(0.875em - 0.1875em);
		left: 0.25em;
	}
	.md\:gr-prose hr {
		border-color: #e5e7eb;
		border-top-width: 1px;
		margin-top: 3em;
		margin-bottom: 3em;
	}
	.md\:gr-prose blockquote {
		font-weight: 500;
		font-style: italic;
		color: #111827;
		border-left-width: 0.25rem;
		border-left-color: #e5e7eb;
		quotes: "\201C""\201D""\2018""\2019";
		margin-top: 1.6em;
		margin-bottom: 1.6em;
		padding-left: 1em;
	}
	.md\:gr-prose blockquote p:first-of-type::before {
		content: open-quote;
	}
	.md\:gr-prose blockquote p:last-of-type::after {
		content: close-quote;
	}
	.md\:gr-prose h1 {
		color: #111827;
		font-weight: 600;
		font-size: 2.25em;
		margin-top: 0;
		margin-bottom: 0.8888889em;
		line-height: 1.1111111;
	}
	.md\:gr-prose h2 {
		color: #111827;
		font-weight: 600;
		font-size: 1.5em;
		margin-top: 2em;
		margin-bottom: 1em;
		line-height: 1.3333333;
	}
	.md\:gr-prose h3 {
		color: #111827;
		font-weight: 600;
		font-size: 1.25em;
		margin-top: 1.6em;
		margin-bottom: 0.6em;
		line-height: 1.6;
	}
	.md\:gr-prose h4 {
		color: #111827;
		font-weight: 600;
		margin-top: 1.5em;
		margin-bottom: 0.5em;
		line-height: 1.5;
	}
	.md\:gr-prose figure figcaption {
		color: #6b7280;
		font-size: 0.875em;
		line-height: 1.4285714;
		margin-top: 0.8571429em;
	}
	.md\:gr-prose code {
		color: #111827;
		font-weight: 600;
		font-size: 0.875em;
	}
	.md\:gr-prose code::before {
		content: "`";
	}
	.md\:gr-prose code::after {
		content: "`";
	}
	.md\:gr-prose a code {
		color: #111827;
	}
	.md\:gr-prose pre {
		color: #e5e7eb;
		background-color: #1f2937;
		overflow-x: auto;
		font-size: 0.875em;
		line-height: 1.7142857;
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
		border-radius: 0.375rem;
		padding-top: 0.8571429em;
		padding-right: 1.1428571em;
		padding-bottom: 0.8571429em;
		padding-left: 1.1428571em;
	}
	.md\:gr-prose pre code {
		background-color: transparent;
		border-width: 0;
		border-radius: 0;
		padding: 0;
		font-weight: 400;
		color: inherit;
		font-size: inherit;
		font-family: inherit;
		line-height: inherit;
	}
	.md\:gr-prose pre code::before {
		content: none;
	}
	.md\:gr-prose pre code::after {
		content: none;
	}
	.md\:gr-prose table {
		width: 100%;
		table-layout: auto;
		text-align: left;
		margin-top: 2em;
		margin-bottom: 2em;
		font-size: 0.875em;
		line-height: 1.7142857;
	}
	.md\:gr-prose thead {
		color: #111827;
		font-weight: 600;
		border-bottom-width: 1px;
		border-bottom-color: #d1d5db;
	}
	.md\:gr-prose thead th {
		vertical-align: bottom;
		padding-right: 0.5714286em;
		padding-bottom: 0.5714286em;
		padding-left: 0.5714286em;
	}
	.md\:gr-prose tbody tr {
		border-bottom-width: 1px;
		border-bottom-color: #e5e7eb;
	}
	.md\:gr-prose tbody tr:last-child {
		border-bottom-width: 0;
	}
	.md\:gr-prose tbody td {
		vertical-align: top;
		padding-top: 0.5714286em;
		padding-right: 0.5714286em;
		padding-bottom: 0.5714286em;
		padding-left: 0.5714286em;
	}
	.md\:gr-prose {
		font-size: 1rem;
		line-height: 1.75;
	}
	.md\:gr-prose p {
		margin-top: 1.25em;
		margin-bottom: 1.25em;
	}
	.md\:gr-prose img {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.md\:gr-prose video {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.md\:gr-prose figure {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.md\:gr-prose figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.md\:gr-prose h2 code {
		font-size: 0.875em;
	}
	.md\:gr-prose h3 code {
		font-size: 0.9em;
	}
	.md\:gr-prose ol {
		margin-top: 1.25em;
		margin-bottom: 1.25em;
	}
	.md\:gr-prose ul {
		margin-top: 1.25em;
		margin-bottom: 1.25em;
	}
	.md\:gr-prose li {
		margin-top: 0.5em;
		margin-bottom: 0.5em;
	}
	.md\:gr-prose > ul > li p {
		margin-top: 0.75em;
		margin-bottom: 0.75em;
	}
	.md\:gr-prose > ul > li > :first-child {
		margin-top: 1.25em;
	}
	.md\:gr-prose > ul > li > :last-child {
		margin-bottom: 1.25em;
	}
	.md\:gr-prose > ol > li > :first-child {
		margin-top: 1.25em;
	}
	.md\:gr-prose > ol > li > :last-child {
		margin-bottom: 1.25em;
	}
	.md\:gr-prose ol ol,
	.md\:gr-prose ol ul,
	.md\:gr-prose ul ol,
	.md\:gr-prose ul ul {
		margin-top: 0.75em;
		margin-bottom: 0.75em;
	}
	.md\:gr-prose hr + * {
		margin-top: 0;
	}
	.md\:gr-prose h2 + * {
		margin-top: 0;
	}
	.md\:gr-prose h3 + * {
		margin-top: 0;
	}
	.md\:gr-prose h4 + * {
		margin-top: 0;
	}
	.md\:gr-prose thead th:first-child {
		padding-left: 0;
	}
	.md\:gr-prose thead th:last-child {
		padding-right: 0;
	}
	.md\:gr-prose tbody td:first-child {
		padding-left: 0;
	}
	.md\:gr-prose tbody td:last-child {
		padding-right: 0;
	}
	.md\:gr-prose > :first-child {
		margin-top: 0;
	}
	.md\:gr-prose > :last-child {
		margin-bottom: 0;
	}
	.md\:gr-prose-sm {
		font-size: 0.875rem;
		line-height: 1.7142857;
	}
	.md\:gr-prose-sm p {
		margin-top: 1.1428571em;
		margin-bottom: 1.1428571em;
	}
	.md\:gr-prose-sm [class~="lead"] {
		font-size: 1.2857143em;
		line-height: 1.5555556;
		margin-top: 0.8888889em;
		margin-bottom: 0.8888889em;
	}
	.md\:gr-prose-sm blockquote {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
		padding-left: 1.1111111em;
	}
	.md\:gr-prose-sm h1 {
		font-size: 2.1428571em;
		margin-top: 0;
		margin-bottom: 0.8em;
		line-height: 1.2;
	}
	.md\:gr-prose-sm h2 {
		font-size: 1.4285714em;
		margin-top: 1.6em;
		margin-bottom: 0.8em;
		line-height: 1.4;
	}
	.md\:gr-prose-sm h3 {
		font-size: 1.2857143em;
		margin-top: 1.5555556em;
		margin-bottom: 0.4444444em;
		line-height: 1.5555556;
	}
	.md\:gr-prose-sm h4 {
		margin-top: 1.4285714em;
		margin-bottom: 0.5714286em;
		line-height: 1.4285714;
	}
	.md\:gr-prose-sm img {
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
	}
	.md\:gr-prose-sm video {
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
	}
	.md\:gr-prose-sm figure {
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
	}
	.md\:gr-prose-sm figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.md\:gr-prose-sm figure figcaption {
		font-size: 0.8571429em;
		line-height: 1.3333333;
		margin-top: 0.6666667em;
	}
	.md\:gr-prose-sm code {
		font-size: 0.8571429em;
	}
	.md\:gr-prose-sm h2 code {
		font-size: 0.9em;
	}
	.md\:gr-prose-sm h3 code {
		font-size: 0.8888889em;
	}
	.md\:gr-prose-sm pre {
		font-size: 0.8571429em;
		line-height: 1.6666667;
		margin-top: 1.6666667em;
		margin-bottom: 1.6666667em;
		border-radius: 0.25rem;
		padding-top: 0.6666667em;
		padding-right: 1em;
		padding-bottom: 0.6666667em;
		padding-left: 1em;
	}
	.md\:gr-prose-sm ol {
		margin-top: 1.1428571em;
		margin-bottom: 1.1428571em;
	}
	.md\:gr-prose-sm ul {
		margin-top: 1.1428571em;
		margin-bottom: 1.1428571em;
	}
	.md\:gr-prose-sm li {
		margin-top: 0.2857143em;
		margin-bottom: 0.2857143em;
	}
	.md\:gr-prose-sm ol > li {
		padding-left: 1.5714286em;
	}
	.md\:gr-prose-sm ol > li::before {
		left: 0;
	}
	.md\:gr-prose-sm ul > li {
		padding-left: 1.5714286em;
	}
	.md\:gr-prose-sm ul > li::before {
		height: 0.3571429em;
		width: 0.3571429em;
		top: calc(0.8571429em - 0.1785714em);
		left: 0.2142857em;
	}
	.md\:gr-prose-sm > ul > li p {
		margin-top: 0.5714286em;
		margin-bottom: 0.5714286em;
	}
	.md\:gr-prose-sm > ul > li > :first-child {
		margin-top: 1.1428571em;
	}
	.md\:gr-prose-sm > ul > li > :last-child {
		margin-bottom: 1.1428571em;
	}
	.md\:gr-prose-sm > ol > li > :first-child {
		margin-top: 1.1428571em;
	}
	.md\:gr-prose-sm > ol > li > :last-child {
		margin-bottom: 1.1428571em;
	}
	.md\:gr-prose-sm ol ol,
	.md\:gr-prose-sm ol ul,
	.md\:gr-prose-sm ul ol,
	.md\:gr-prose-sm ul ul {
		margin-top: 0.5714286em;
		margin-bottom: 0.5714286em;
	}
	.md\:gr-prose-sm hr {
		margin-top: 2.8571429em;
		margin-bottom: 2.8571429em;
	}
	.md\:gr-prose-sm hr + * {
		margin-top: 0;
	}
	.md\:gr-prose-sm h2 + * {
		margin-top: 0;
	}
	.md\:gr-prose-sm h3 + * {
		margin-top: 0;
	}
	.md\:gr-prose-sm h4 + * {
		margin-top: 0;
	}
	.md\:gr-prose-sm table {
		font-size: 0.8571429em;
		line-height: 1.5;
	}
	.md\:gr-prose-sm thead th {
		padding-right: 1em;
		padding-bottom: 0.6666667em;
		padding-left: 1em;
	}
	.md\:gr-prose-sm thead th:first-child {
		padding-left: 0;
	}
	.md\:gr-prose-sm thead th:last-child {
		padding-right: 0;
	}
	.md\:gr-prose-sm tbody td {
		padding-top: 0.6666667em;
		padding-right: 1em;
		padding-bottom: 0.6666667em;
		padding-left: 1em;
	}
	.md\:gr-prose-sm tbody td:first-child {
		padding-left: 0;
	}
	.md\:gr-prose-sm tbody td:last-child {
		padding-right: 0;
	}
	.md\:gr-prose-sm > :first-child {
		margin-top: 0;
	}
	.md\:gr-prose-sm > :last-child {
		margin-bottom: 0;
	}
	.md\:gr-prose-lg {
		font-size: 1.125rem;
		line-height: 1.7777778;
	}
	.md\:gr-prose-lg p {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.md\:gr-prose-lg [class~="lead"] {
		font-size: 1.2222222em;
		line-height: 1.4545455;
		margin-top: 1.0909091em;
		margin-bottom: 1.0909091em;
	}
	.md\:gr-prose-lg blockquote {
		margin-top: 1.6666667em;
		margin-bottom: 1.6666667em;
		padding-left: 1em;
	}
	.md\:gr-prose-lg h1 {
		font-size: 2.6666667em;
		margin-top: 0;
		margin-bottom: 0.8333333em;
		line-height: 1;
	}
	.md\:gr-prose-lg h2 {
		font-size: 1.6666667em;
		margin-top: 1.8666667em;
		margin-bottom: 1.0666667em;
		line-height: 1.3333333;
	}
	.md\:gr-prose-lg h3 {
		font-size: 1.3333333em;
		margin-top: 1.6666667em;
		margin-bottom: 0.6666667em;
		line-height: 1.5;
	}
	.md\:gr-prose-lg h4 {
		margin-top: 1.7777778em;
		margin-bottom: 0.4444444em;
		line-height: 1.5555556;
	}
	.md\:gr-prose-lg img {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
	}
	.md\:gr-prose-lg video {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
	}
	.md\:gr-prose-lg figure {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
	}
	.md\:gr-prose-lg figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.md\:gr-prose-lg figure figcaption {
		font-size: 0.8888889em;
		line-height: 1.5;
		margin-top: 1em;
	}
	.md\:gr-prose-lg code {
		font-size: 0.8888889em;
	}
	.md\:gr-prose-lg h2 code {
		font-size: 0.8666667em;
	}
	.md\:gr-prose-lg h3 code {
		font-size: 0.875em;
	}
	.md\:gr-prose-lg pre {
		font-size: 0.8888889em;
		line-height: 1.75;
		margin-top: 2em;
		margin-bottom: 2em;
		border-radius: 0.375rem;
		padding-top: 1em;
		padding-right: 1.5em;
		padding-bottom: 1em;
		padding-left: 1.5em;
	}
	.md\:gr-prose-lg ol {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.md\:gr-prose-lg ul {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.md\:gr-prose-lg li {
		margin-top: 0.6666667em;
		margin-bottom: 0.6666667em;
	}
	.md\:gr-prose-lg ol > li {
		padding-left: 1.6666667em;
	}
	.md\:gr-prose-lg ol > li::before {
		left: 0;
	}
	.md\:gr-prose-lg ul > li {
		padding-left: 1.6666667em;
	}
	.md\:gr-prose-lg ul > li::before {
		width: 0.3333333em;
		height: 0.3333333em;
		top: calc(0.8888889em - 0.1666667em);
		left: 0.2222222em;
	}
	.md\:gr-prose-lg > ul > li p {
		margin-top: 0.8888889em;
		margin-bottom: 0.8888889em;
	}
	.md\:gr-prose-lg > ul > li > :first-child {
		margin-top: 1.3333333em;
	}
	.md\:gr-prose-lg > ul > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.md\:gr-prose-lg > ol > li > :first-child {
		margin-top: 1.3333333em;
	}
	.md\:gr-prose-lg > ol > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.md\:gr-prose-lg ol ol,
	.md\:gr-prose-lg ol ul,
	.md\:gr-prose-lg ul ol,
	.md\:gr-prose-lg ul ul {
		margin-top: 0.8888889em;
		margin-bottom: 0.8888889em;
	}
	.md\:gr-prose-lg hr {
		margin-top: 3.1111111em;
		margin-bottom: 3.1111111em;
	}
	.md\:gr-prose-lg hr + * {
		margin-top: 0;
	}
	.md\:gr-prose-lg h2 + * {
		margin-top: 0;
	}
	.md\:gr-prose-lg h3 + * {
		margin-top: 0;
	}
	.md\:gr-prose-lg h4 + * {
		margin-top: 0;
	}
	.md\:gr-prose-lg table {
		font-size: 0.8888889em;
		line-height: 1.5;
	}
	.md\:gr-prose-lg thead th {
		padding-right: 0.75em;
		padding-bottom: 0.75em;
		padding-left: 0.75em;
	}
	.md\:gr-prose-lg thead th:first-child {
		padding-left: 0;
	}
	.md\:gr-prose-lg thead th:last-child {
		padding-right: 0;
	}
	.md\:gr-prose-lg tbody td {
		padding-top: 0.75em;
		padding-right: 0.75em;
		padding-bottom: 0.75em;
		padding-left: 0.75em;
	}
	.md\:gr-prose-lg tbody td:first-child {
		padding-left: 0;
	}
	.md\:gr-prose-lg tbody td:last-child {
		padding-right: 0;
	}
	.md\:gr-prose-lg > :first-child {
		margin-top: 0;
	}
	.md\:gr-prose-lg > :last-child {
		margin-bottom: 0;
	}
	.md\:gr-prose-xl {
		font-size: 1.25rem;
		line-height: 1.8;
	}
	.md\:gr-prose-xl p {
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.md\:gr-prose-xl [class~="lead"] {
		font-size: 1.2em;
		line-height: 1.5;
		margin-top: 1em;
		margin-bottom: 1em;
	}
	.md\:gr-prose-xl blockquote {
		margin-top: 1.6em;
		margin-bottom: 1.6em;
		padding-left: 1.0666667em;
	}
	.md\:gr-prose-xl h1 {
		font-size: 2.8em;
		margin-top: 0;
		margin-bottom: 0.8571429em;
		line-height: 1;
	}
	.md\:gr-prose-xl h2 {
		font-size: 1.8em;
		margin-top: 1.5555556em;
		margin-bottom: 0.8888889em;
		line-height: 1.1111111;
	}
	.md\:gr-prose-xl h3 {
		font-size: 1.5em;
		margin-top: 1.6em;
		margin-bottom: 0.6666667em;
		line-height: 1.3333333;
	}
	.md\:gr-prose-xl h4 {
		margin-top: 1.8em;
		margin-bottom: 0.6em;
		line-height: 1.6;
	}
	.md\:gr-prose-xl img {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.md\:gr-prose-xl video {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.md\:gr-prose-xl figure {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.md\:gr-prose-xl figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.md\:gr-prose-xl figure figcaption {
		font-size: 0.9em;
		line-height: 1.5555556;
		margin-top: 1em;
	}
	.md\:gr-prose-xl code {
		font-size: 0.9em;
	}
	.md\:gr-prose-xl h2 code {
		font-size: 0.8611111em;
	}
	.md\:gr-prose-xl h3 code {
		font-size: 0.9em;
	}
	.md\:gr-prose-xl pre {
		font-size: 0.9em;
		line-height: 1.7777778;
		margin-top: 2em;
		margin-bottom: 2em;
		border-radius: 0.5rem;
		padding-top: 1.1111111em;
		padding-right: 1.3333333em;
		padding-bottom: 1.1111111em;
		padding-left: 1.3333333em;
	}
	.md\:gr-prose-xl ol {
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.md\:gr-prose-xl ul {
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.md\:gr-prose-xl li {
		margin-top: 0.6em;
		margin-bottom: 0.6em;
	}
	.md\:gr-prose-xl ol > li {
		padding-left: 1.8em;
	}
	.md\:gr-prose-xl ol > li::before {
		left: 0;
	}
	.md\:gr-prose-xl ul > li {
		padding-left: 1.8em;
	}
	.md\:gr-prose-xl ul > li::before {
		width: 0.35em;
		height: 0.35em;
		top: calc(0.9em - 0.175em);
		left: 0.25em;
	}
	.md\:gr-prose-xl > ul > li p {
		margin-top: 0.8em;
		margin-bottom: 0.8em;
	}
	.md\:gr-prose-xl > ul > li > :first-child {
		margin-top: 1.2em;
	}
	.md\:gr-prose-xl > ul > li > :last-child {
		margin-bottom: 1.2em;
	}
	.md\:gr-prose-xl > ol > li > :first-child {
		margin-top: 1.2em;
	}
	.md\:gr-prose-xl > ol > li > :last-child {
		margin-bottom: 1.2em;
	}
	.md\:gr-prose-xl ol ol,
	.md\:gr-prose-xl ol ul,
	.md\:gr-prose-xl ul ol,
	.md\:gr-prose-xl ul ul {
		margin-top: 0.8em;
		margin-bottom: 0.8em;
	}
	.md\:gr-prose-xl hr {
		margin-top: 2.8em;
		margin-bottom: 2.8em;
	}
	.md\:gr-prose-xl hr + * {
		margin-top: 0;
	}
	.md\:gr-prose-xl h2 + * {
		margin-top: 0;
	}
	.md\:gr-prose-xl h3 + * {
		margin-top: 0;
	}
	.md\:gr-prose-xl h4 + * {
		margin-top: 0;
	}
	.md\:gr-prose-xl table {
		font-size: 0.9em;
		line-height: 1.5555556;
	}
	.md\:gr-prose-xl thead th {
		padding-right: 0.6666667em;
		padding-bottom: 0.8888889em;
		padding-left: 0.6666667em;
	}
	.md\:gr-prose-xl thead th:first-child {
		padding-left: 0;
	}
	.md\:gr-prose-xl thead th:last-child {
		padding-right: 0;
	}
	.md\:gr-prose-xl tbody td {
		padding-top: 0.8888889em;
		padding-right: 0.6666667em;
		padding-bottom: 0.8888889em;
		padding-left: 0.6666667em;
	}
	.md\:gr-prose-xl tbody td:first-child {
		padding-left: 0;
	}
	.md\:gr-prose-xl tbody td:last-child {
		padding-right: 0;
	}
	.md\:gr-prose-xl > :first-child {
		margin-top: 0;
	}
	.md\:gr-prose-xl > :last-child {
		margin-bottom: 0;
	}
	.md\:gr-prose-2xl {
		font-size: 1.5rem;
		line-height: 1.6666667;
	}
	.md\:gr-prose-2xl p {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.md\:gr-prose-2xl [class~="lead"] {
		font-size: 1.25em;
		line-height: 1.4666667;
		margin-top: 1.0666667em;
		margin-bottom: 1.0666667em;
	}
	.md\:gr-prose-2xl blockquote {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
		padding-left: 1.1111111em;
	}
	.md\:gr-prose-2xl h1 {
		font-size: 2.6666667em;
		margin-top: 0;
		margin-bottom: 0.875em;
		line-height: 1;
	}
	.md\:gr-prose-2xl h2 {
		font-size: 2em;
		margin-top: 1.5em;
		margin-bottom: 0.8333333em;
		line-height: 1.0833333;
	}
	.md\:gr-prose-2xl h3 {
		font-size: 1.5em;
		margin-top: 1.5555556em;
		margin-bottom: 0.6666667em;
		line-height: 1.2222222;
	}
	.md\:gr-prose-2xl h4 {
		margin-top: 1.6666667em;
		margin-bottom: 0.6666667em;
		line-height: 1.5;
	}
	.md\:gr-prose-2xl img {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.md\:gr-prose-2xl video {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.md\:gr-prose-2xl figure {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.md\:gr-prose-2xl figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.md\:gr-prose-2xl figure figcaption {
		font-size: 0.8333333em;
		line-height: 1.6;
		margin-top: 1em;
	}
	.md\:gr-prose-2xl code {
		font-size: 0.8333333em;
	}
	.md\:gr-prose-2xl h2 code {
		font-size: 0.875em;
	}
	.md\:gr-prose-2xl h3 code {
		font-size: 0.8888889em;
	}
	.md\:gr-prose-2xl pre {
		font-size: 0.8333333em;
		line-height: 1.8;
		margin-top: 2em;
		margin-bottom: 2em;
		border-radius: 0.5rem;
		padding-top: 1.2em;
		padding-right: 1.6em;
		padding-bottom: 1.2em;
		padding-left: 1.6em;
	}
	.md\:gr-prose-2xl ol {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.md\:gr-prose-2xl ul {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.md\:gr-prose-2xl li {
		margin-top: 0.5em;
		margin-bottom: 0.5em;
	}
	.md\:gr-prose-2xl ol > li {
		padding-left: 1.6666667em;
	}
	.md\:gr-prose-2xl ol > li::before {
		left: 0;
	}
	.md\:gr-prose-2xl ul > li {
		padding-left: 1.6666667em;
	}
	.md\:gr-prose-2xl ul > li::before {
		width: 0.3333333em;
		height: 0.3333333em;
		top: calc(0.8333333em - 0.1666667em);
		left: 0.25em;
	}
	.md\:gr-prose-2xl > ul > li p {
		margin-top: 0.8333333em;
		margin-bottom: 0.8333333em;
	}
	.md\:gr-prose-2xl > ul > li > :first-child {
		margin-top: 1.3333333em;
	}
	.md\:gr-prose-2xl > ul > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.md\:gr-prose-2xl > ol > li > :first-child {
		margin-top: 1.3333333em;
	}
	.md\:gr-prose-2xl > ol > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.md\:gr-prose-2xl ol ol,
	.md\:gr-prose-2xl ol ul,
	.md\:gr-prose-2xl ul ol,
	.md\:gr-prose-2xl ul ul {
		margin-top: 0.6666667em;
		margin-bottom: 0.6666667em;
	}
	.md\:gr-prose-2xl hr {
		margin-top: 3em;
		margin-bottom: 3em;
	}
	.md\:gr-prose-2xl hr + * {
		margin-top: 0;
	}
	.md\:gr-prose-2xl h2 + * {
		margin-top: 0;
	}
	.md\:gr-prose-2xl h3 + * {
		margin-top: 0;
	}
	.md\:gr-prose-2xl h4 + * {
		margin-top: 0;
	}
	.md\:gr-prose-2xl table {
		font-size: 0.8333333em;
		line-height: 1.4;
	}
	.md\:gr-prose-2xl thead th {
		padding-right: 0.6em;
		padding-bottom: 0.8em;
		padding-left: 0.6em;
	}
	.md\:gr-prose-2xl thead th:first-child {
		padding-left: 0;
	}
	.md\:gr-prose-2xl thead th:last-child {
		padding-right: 0;
	}
	.md\:gr-prose-2xl tbody td {
		padding-top: 0.8em;
		padding-right: 0.6em;
		padding-bottom: 0.8em;
		padding-left: 0.6em;
	}
	.md\:gr-prose-2xl tbody td:first-child {
		padding-left: 0;
	}
	.md\:gr-prose-2xl tbody td:last-child {
		padding-right: 0;
	}
	.md\:gr-prose-2xl > :first-child {
		margin-top: 0;
	}
	.md\:gr-prose-2xl > :last-child {
		margin-bottom: 0;
	}
	.md\:gr-prose-red a {
		color: #dc2626;
	}
	.md\:gr-prose-red a code {
		color: #dc2626;
	}
	.md\:gr-prose-yellow a {
		color: #d97706;
	}
	.md\:gr-prose-yellow a code {
		color: #d97706;
	}
	.md\:gr-prose-green a {
		color: #059669;
	}
	.md\:gr-prose-green a code {
		color: #059669;
	}
	.md\:gr-prose-blue a {
		color: #2563eb;
	}
	.md\:gr-prose-blue a code {
		color: #2563eb;
	}
	.md\:gr-prose-indigo a {
		color: #4f46e5;
	}
	.md\:gr-prose-indigo a code {
		color: #4f46e5;
	}
	.md\:gr-prose-purple a {
		color: #7c3aed;
	}
	.md\:gr-prose-purple a code {
		color: #7c3aed;
	}
	.md\:gr-prose-pink a {
		color: #db2777;
	}
	.md\:gr-prose-pink a code {
		color: #db2777;
	}
}
@media (min-width: 1024px) {
	.lg\:gr-prose {
		color: #374151;
		max-width: 65ch;
	}
	.lg\:gr-prose [class~="lead"] {
		color: #4b5563;
		font-size: 1.25em;
		line-height: 1.6;
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.lg\:gr-prose a {
		color: #111827;
		text-decoration: underline;
		font-weight: 500;
	}
	.lg\:gr-prose strong {
		color: #111827;
		font-weight: 600;
	}
	.lg\:gr-prose ol[type="A"] {
		--list-counter-style: upper-alpha;
	}
	.lg\:gr-prose ol[type="a"] {
		--list-counter-style: lower-alpha;
	}
	.lg\:gr-prose ol[type="A"s] {
		--list-counter-style: upper-alpha;
	}
	.lg\:gr-prose ol[type="a"s] {
		--list-counter-style: lower-alpha;
	}
	.lg\:gr-prose ol[type="I"] {
		--list-counter-style: upper-roman;
	}
	.lg\:gr-prose ol[type="i"] {
		--list-counter-style: lower-roman;
	}
	.lg\:gr-prose ol[type="I"s] {
		--list-counter-style: upper-roman;
	}
	.lg\:gr-prose ol[type="i"s] {
		--list-counter-style: lower-roman;
	}
	.lg\:gr-prose ol[type="1"] {
		--list-counter-style: decimal;
	}
	.lg\:gr-prose ol > li {
		position: relative;
		padding-left: 1.75em;
	}
	.lg\:gr-prose ol > li::before {
		content: counter(list-item, var(--list-counter-style, decimal)) ".";
		position: absolute;
		font-weight: 400;
		color: #6b7280;
		left: 0;
	}
	.lg\:gr-prose ul > li {
		position: relative;
		padding-left: 1.75em;
	}
	.lg\:gr-prose ul > li::before {
		content: "";
		position: absolute;
		background-color: #d1d5db;
		border-radius: 50%;
		width: 0.375em;
		height: 0.375em;
		top: calc(0.875em - 0.1875em);
		left: 0.25em;
	}
	.lg\:gr-prose hr {
		border-color: #e5e7eb;
		border-top-width: 1px;
		margin-top: 3em;
		margin-bottom: 3em;
	}
	.lg\:gr-prose blockquote {
		font-weight: 500;
		font-style: italic;
		color: #111827;
		border-left-width: 0.25rem;
		border-left-color: #e5e7eb;
		quotes: "\201C""\201D""\2018""\2019";
		margin-top: 1.6em;
		margin-bottom: 1.6em;
		padding-left: 1em;
	}
	.lg\:gr-prose blockquote p:first-of-type::before {
		content: open-quote;
	}
	.lg\:gr-prose blockquote p:last-of-type::after {
		content: close-quote;
	}
	.lg\:gr-prose h1 {
		color: #111827;
		font-weight: 600;
		font-size: 2.25em;
		margin-top: 0;
		margin-bottom: 0.8888889em;
		line-height: 1.1111111;
	}
	.lg\:gr-prose h2 {
		color: #111827;
		font-weight: 600;
		font-size: 1.5em;
		margin-top: 2em;
		margin-bottom: 1em;
		line-height: 1.3333333;
	}
	.lg\:gr-prose h3 {
		color: #111827;
		font-weight: 600;
		font-size: 1.25em;
		margin-top: 1.6em;
		margin-bottom: 0.6em;
		line-height: 1.6;
	}
	.lg\:gr-prose h4 {
		color: #111827;
		font-weight: 600;
		margin-top: 1.5em;
		margin-bottom: 0.5em;
		line-height: 1.5;
	}
	.lg\:gr-prose figure figcaption {
		color: #6b7280;
		font-size: 0.875em;
		line-height: 1.4285714;
		margin-top: 0.8571429em;
	}
	.lg\:gr-prose code {
		color: #111827;
		font-weight: 600;
		font-size: 0.875em;
	}
	.lg\:gr-prose code::before {
		content: "`";
	}
	.lg\:gr-prose code::after {
		content: "`";
	}
	.lg\:gr-prose a code {
		color: #111827;
	}
	.lg\:gr-prose pre {
		color: #e5e7eb;
		background-color: #1f2937;
		overflow-x: auto;
		font-size: 0.875em;
		line-height: 1.7142857;
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
		border-radius: 0.375rem;
		padding-top: 0.8571429em;
		padding-right: 1.1428571em;
		padding-bottom: 0.8571429em;
		padding-left: 1.1428571em;
	}
	.lg\:gr-prose pre code {
		background-color: transparent;
		border-width: 0;
		border-radius: 0;
		padding: 0;
		font-weight: 400;
		color: inherit;
		font-size: inherit;
		font-family: inherit;
		line-height: inherit;
	}
	.lg\:gr-prose pre code::before {
		content: none;
	}
	.lg\:gr-prose pre code::after {
		content: none;
	}
	.lg\:gr-prose table {
		width: 100%;
		table-layout: auto;
		text-align: left;
		margin-top: 2em;
		margin-bottom: 2em;
		font-size: 0.875em;
		line-height: 1.7142857;
	}
	.lg\:gr-prose thead {
		color: #111827;
		font-weight: 600;
		border-bottom-width: 1px;
		border-bottom-color: #d1d5db;
	}
	.lg\:gr-prose thead th {
		vertical-align: bottom;
		padding-right: 0.5714286em;
		padding-bottom: 0.5714286em;
		padding-left: 0.5714286em;
	}
	.lg\:gr-prose tbody tr {
		border-bottom-width: 1px;
		border-bottom-color: #e5e7eb;
	}
	.lg\:gr-prose tbody tr:last-child {
		border-bottom-width: 0;
	}
	.lg\:gr-prose tbody td {
		vertical-align: top;
		padding-top: 0.5714286em;
		padding-right: 0.5714286em;
		padding-bottom: 0.5714286em;
		padding-left: 0.5714286em;
	}
	.lg\:gr-prose {
		font-size: 1rem;
		line-height: 1.75;
	}
	.lg\:gr-prose p {
		margin-top: 1.25em;
		margin-bottom: 1.25em;
	}
	.lg\:gr-prose img {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.lg\:gr-prose video {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.lg\:gr-prose figure {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.lg\:gr-prose figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.lg\:gr-prose h2 code {
		font-size: 0.875em;
	}
	.lg\:gr-prose h3 code {
		font-size: 0.9em;
	}
	.lg\:gr-prose ol {
		margin-top: 1.25em;
		margin-bottom: 1.25em;
	}
	.lg\:gr-prose ul {
		margin-top: 1.25em;
		margin-bottom: 1.25em;
	}
	.lg\:gr-prose li {
		margin-top: 0.5em;
		margin-bottom: 0.5em;
	}
	.lg\:gr-prose > ul > li p {
		margin-top: 0.75em;
		margin-bottom: 0.75em;
	}
	.lg\:gr-prose > ul > li > :first-child {
		margin-top: 1.25em;
	}
	.lg\:gr-prose > ul > li > :last-child {
		margin-bottom: 1.25em;
	}
	.lg\:gr-prose > ol > li > :first-child {
		margin-top: 1.25em;
	}
	.lg\:gr-prose > ol > li > :last-child {
		margin-bottom: 1.25em;
	}
	.lg\:gr-prose ol ol,
	.lg\:gr-prose ol ul,
	.lg\:gr-prose ul ol,
	.lg\:gr-prose ul ul {
		margin-top: 0.75em;
		margin-bottom: 0.75em;
	}
	.lg\:gr-prose hr + * {
		margin-top: 0;
	}
	.lg\:gr-prose h2 + * {
		margin-top: 0;
	}
	.lg\:gr-prose h3 + * {
		margin-top: 0;
	}
	.lg\:gr-prose h4 + * {
		margin-top: 0;
	}
	.lg\:gr-prose thead th:first-child {
		padding-left: 0;
	}
	.lg\:gr-prose thead th:last-child {
		padding-right: 0;
	}
	.lg\:gr-prose tbody td:first-child {
		padding-left: 0;
	}
	.lg\:gr-prose tbody td:last-child {
		padding-right: 0;
	}
	.lg\:gr-prose > :first-child {
		margin-top: 0;
	}
	.lg\:gr-prose > :last-child {
		margin-bottom: 0;
	}
	.lg\:gr-prose-sm {
		font-size: 0.875rem;
		line-height: 1.7142857;
	}
	.lg\:gr-prose-sm p {
		margin-top: 1.1428571em;
		margin-bottom: 1.1428571em;
	}
	.lg\:gr-prose-sm [class~="lead"] {
		font-size: 1.2857143em;
		line-height: 1.5555556;
		margin-top: 0.8888889em;
		margin-bottom: 0.8888889em;
	}
	.lg\:gr-prose-sm blockquote {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
		padding-left: 1.1111111em;
	}
	.lg\:gr-prose-sm h1 {
		font-size: 2.1428571em;
		margin-top: 0;
		margin-bottom: 0.8em;
		line-height: 1.2;
	}
	.lg\:gr-prose-sm h2 {
		font-size: 1.4285714em;
		margin-top: 1.6em;
		margin-bottom: 0.8em;
		line-height: 1.4;
	}
	.lg\:gr-prose-sm h3 {
		font-size: 1.2857143em;
		margin-top: 1.5555556em;
		margin-bottom: 0.4444444em;
		line-height: 1.5555556;
	}
	.lg\:gr-prose-sm h4 {
		margin-top: 1.4285714em;
		margin-bottom: 0.5714286em;
		line-height: 1.4285714;
	}
	.lg\:gr-prose-sm img {
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
	}
	.lg\:gr-prose-sm video {
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
	}
	.lg\:gr-prose-sm figure {
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
	}
	.lg\:gr-prose-sm figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.lg\:gr-prose-sm figure figcaption {
		font-size: 0.8571429em;
		line-height: 1.3333333;
		margin-top: 0.6666667em;
	}
	.lg\:gr-prose-sm code {
		font-size: 0.8571429em;
	}
	.lg\:gr-prose-sm h2 code {
		font-size: 0.9em;
	}
	.lg\:gr-prose-sm h3 code {
		font-size: 0.8888889em;
	}
	.lg\:gr-prose-sm pre {
		font-size: 0.8571429em;
		line-height: 1.6666667;
		margin-top: 1.6666667em;
		margin-bottom: 1.6666667em;
		border-radius: 0.25rem;
		padding-top: 0.6666667em;
		padding-right: 1em;
		padding-bottom: 0.6666667em;
		padding-left: 1em;
	}
	.lg\:gr-prose-sm ol {
		margin-top: 1.1428571em;
		margin-bottom: 1.1428571em;
	}
	.lg\:gr-prose-sm ul {
		margin-top: 1.1428571em;
		margin-bottom: 1.1428571em;
	}
	.lg\:gr-prose-sm li {
		margin-top: 0.2857143em;
		margin-bottom: 0.2857143em;
	}
	.lg\:gr-prose-sm ol > li {
		padding-left: 1.5714286em;
	}
	.lg\:gr-prose-sm ol > li::before {
		left: 0;
	}
	.lg\:gr-prose-sm ul > li {
		padding-left: 1.5714286em;
	}
	.lg\:gr-prose-sm ul > li::before {
		height: 0.3571429em;
		width: 0.3571429em;
		top: calc(0.8571429em - 0.1785714em);
		left: 0.2142857em;
	}
	.lg\:gr-prose-sm > ul > li p {
		margin-top: 0.5714286em;
		margin-bottom: 0.5714286em;
	}
	.lg\:gr-prose-sm > ul > li > :first-child {
		margin-top: 1.1428571em;
	}
	.lg\:gr-prose-sm > ul > li > :last-child {
		margin-bottom: 1.1428571em;
	}
	.lg\:gr-prose-sm > ol > li > :first-child {
		margin-top: 1.1428571em;
	}
	.lg\:gr-prose-sm > ol > li > :last-child {
		margin-bottom: 1.1428571em;
	}
	.lg\:gr-prose-sm ol ol,
	.lg\:gr-prose-sm ol ul,
	.lg\:gr-prose-sm ul ol,
	.lg\:gr-prose-sm ul ul {
		margin-top: 0.5714286em;
		margin-bottom: 0.5714286em;
	}
	.lg\:gr-prose-sm hr {
		margin-top: 2.8571429em;
		margin-bottom: 2.8571429em;
	}
	.lg\:gr-prose-sm hr + * {
		margin-top: 0;
	}
	.lg\:gr-prose-sm h2 + * {
		margin-top: 0;
	}
	.lg\:gr-prose-sm h3 + * {
		margin-top: 0;
	}
	.lg\:gr-prose-sm h4 + * {
		margin-top: 0;
	}
	.lg\:gr-prose-sm table {
		font-size: 0.8571429em;
		line-height: 1.5;
	}
	.lg\:gr-prose-sm thead th {
		padding-right: 1em;
		padding-bottom: 0.6666667em;
		padding-left: 1em;
	}
	.lg\:gr-prose-sm thead th:first-child {
		padding-left: 0;
	}
	.lg\:gr-prose-sm thead th:last-child {
		padding-right: 0;
	}
	.lg\:gr-prose-sm tbody td {
		padding-top: 0.6666667em;
		padding-right: 1em;
		padding-bottom: 0.6666667em;
		padding-left: 1em;
	}
	.lg\:gr-prose-sm tbody td:first-child {
		padding-left: 0;
	}
	.lg\:gr-prose-sm tbody td:last-child {
		padding-right: 0;
	}
	.lg\:gr-prose-sm > :first-child {
		margin-top: 0;
	}
	.lg\:gr-prose-sm > :last-child {
		margin-bottom: 0;
	}
	.lg\:gr-prose-lg {
		font-size: 1.125rem;
		line-height: 1.7777778;
	}
	.lg\:gr-prose-lg p {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.lg\:gr-prose-lg [class~="lead"] {
		font-size: 1.2222222em;
		line-height: 1.4545455;
		margin-top: 1.0909091em;
		margin-bottom: 1.0909091em;
	}
	.lg\:gr-prose-lg blockquote {
		margin-top: 1.6666667em;
		margin-bottom: 1.6666667em;
		padding-left: 1em;
	}
	.lg\:gr-prose-lg h1 {
		font-size: 2.6666667em;
		margin-top: 0;
		margin-bottom: 0.8333333em;
		line-height: 1;
	}
	.lg\:gr-prose-lg h2 {
		font-size: 1.6666667em;
		margin-top: 1.8666667em;
		margin-bottom: 1.0666667em;
		line-height: 1.3333333;
	}
	.lg\:gr-prose-lg h3 {
		font-size: 1.3333333em;
		margin-top: 1.6666667em;
		margin-bottom: 0.6666667em;
		line-height: 1.5;
	}
	.lg\:gr-prose-lg h4 {
		margin-top: 1.7777778em;
		margin-bottom: 0.4444444em;
		line-height: 1.5555556;
	}
	.lg\:gr-prose-lg img {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
	}
	.lg\:gr-prose-lg video {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
	}
	.lg\:gr-prose-lg figure {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
	}
	.lg\:gr-prose-lg figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.lg\:gr-prose-lg figure figcaption {
		font-size: 0.8888889em;
		line-height: 1.5;
		margin-top: 1em;
	}
	.lg\:gr-prose-lg code {
		font-size: 0.8888889em;
	}
	.lg\:gr-prose-lg h2 code {
		font-size: 0.8666667em;
	}
	.lg\:gr-prose-lg h3 code {
		font-size: 0.875em;
	}
	.lg\:gr-prose-lg pre {
		font-size: 0.8888889em;
		line-height: 1.75;
		margin-top: 2em;
		margin-bottom: 2em;
		border-radius: 0.375rem;
		padding-top: 1em;
		padding-right: 1.5em;
		padding-bottom: 1em;
		padding-left: 1.5em;
	}
	.lg\:gr-prose-lg ol {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.lg\:gr-prose-lg ul {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.lg\:gr-prose-lg li {
		margin-top: 0.6666667em;
		margin-bottom: 0.6666667em;
	}
	.lg\:gr-prose-lg ol > li {
		padding-left: 1.6666667em;
	}
	.lg\:gr-prose-lg ol > li::before {
		left: 0;
	}
	.lg\:gr-prose-lg ul > li {
		padding-left: 1.6666667em;
	}
	.lg\:gr-prose-lg ul > li::before {
		width: 0.3333333em;
		height: 0.3333333em;
		top: calc(0.8888889em - 0.1666667em);
		left: 0.2222222em;
	}
	.lg\:gr-prose-lg > ul > li p {
		margin-top: 0.8888889em;
		margin-bottom: 0.8888889em;
	}
	.lg\:gr-prose-lg > ul > li > :first-child {
		margin-top: 1.3333333em;
	}
	.lg\:gr-prose-lg > ul > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.lg\:gr-prose-lg > ol > li > :first-child {
		margin-top: 1.3333333em;
	}
	.lg\:gr-prose-lg > ol > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.lg\:gr-prose-lg ol ol,
	.lg\:gr-prose-lg ol ul,
	.lg\:gr-prose-lg ul ol,
	.lg\:gr-prose-lg ul ul {
		margin-top: 0.8888889em;
		margin-bottom: 0.8888889em;
	}
	.lg\:gr-prose-lg hr {
		margin-top: 3.1111111em;
		margin-bottom: 3.1111111em;
	}
	.lg\:gr-prose-lg hr + * {
		margin-top: 0;
	}
	.lg\:gr-prose-lg h2 + * {
		margin-top: 0;
	}
	.lg\:gr-prose-lg h3 + * {
		margin-top: 0;
	}
	.lg\:gr-prose-lg h4 + * {
		margin-top: 0;
	}
	.lg\:gr-prose-lg table {
		font-size: 0.8888889em;
		line-height: 1.5;
	}
	.lg\:gr-prose-lg thead th {
		padding-right: 0.75em;
		padding-bottom: 0.75em;
		padding-left: 0.75em;
	}
	.lg\:gr-prose-lg thead th:first-child {
		padding-left: 0;
	}
	.lg\:gr-prose-lg thead th:last-child {
		padding-right: 0;
	}
	.lg\:gr-prose-lg tbody td {
		padding-top: 0.75em;
		padding-right: 0.75em;
		padding-bottom: 0.75em;
		padding-left: 0.75em;
	}
	.lg\:gr-prose-lg tbody td:first-child {
		padding-left: 0;
	}
	.lg\:gr-prose-lg tbody td:last-child {
		padding-right: 0;
	}
	.lg\:gr-prose-lg > :first-child {
		margin-top: 0;
	}
	.lg\:gr-prose-lg > :last-child {
		margin-bottom: 0;
	}
	.lg\:gr-prose-xl {
		font-size: 1.25rem;
		line-height: 1.8;
	}
	.lg\:gr-prose-xl p {
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.lg\:gr-prose-xl [class~="lead"] {
		font-size: 1.2em;
		line-height: 1.5;
		margin-top: 1em;
		margin-bottom: 1em;
	}
	.lg\:gr-prose-xl blockquote {
		margin-top: 1.6em;
		margin-bottom: 1.6em;
		padding-left: 1.0666667em;
	}
	.lg\:gr-prose-xl h1 {
		font-size: 2.8em;
		margin-top: 0;
		margin-bottom: 0.8571429em;
		line-height: 1;
	}
	.lg\:gr-prose-xl h2 {
		font-size: 1.8em;
		margin-top: 1.5555556em;
		margin-bottom: 0.8888889em;
		line-height: 1.1111111;
	}
	.lg\:gr-prose-xl h3 {
		font-size: 1.5em;
		margin-top: 1.6em;
		margin-bottom: 0.6666667em;
		line-height: 1.3333333;
	}
	.lg\:gr-prose-xl h4 {
		margin-top: 1.8em;
		margin-bottom: 0.6em;
		line-height: 1.6;
	}
	.lg\:gr-prose-xl img {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.lg\:gr-prose-xl video {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.lg\:gr-prose-xl figure {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.lg\:gr-prose-xl figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.lg\:gr-prose-xl figure figcaption {
		font-size: 0.9em;
		line-height: 1.5555556;
		margin-top: 1em;
	}
	.lg\:gr-prose-xl code {
		font-size: 0.9em;
	}
	.lg\:gr-prose-xl h2 code {
		font-size: 0.8611111em;
	}
	.lg\:gr-prose-xl h3 code {
		font-size: 0.9em;
	}
	.lg\:gr-prose-xl pre {
		font-size: 0.9em;
		line-height: 1.7777778;
		margin-top: 2em;
		margin-bottom: 2em;
		border-radius: 0.5rem;
		padding-top: 1.1111111em;
		padding-right: 1.3333333em;
		padding-bottom: 1.1111111em;
		padding-left: 1.3333333em;
	}
	.lg\:gr-prose-xl ol {
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.lg\:gr-prose-xl ul {
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.lg\:gr-prose-xl li {
		margin-top: 0.6em;
		margin-bottom: 0.6em;
	}
	.lg\:gr-prose-xl ol > li {
		padding-left: 1.8em;
	}
	.lg\:gr-prose-xl ol > li::before {
		left: 0;
	}
	.lg\:gr-prose-xl ul > li {
		padding-left: 1.8em;
	}
	.lg\:gr-prose-xl ul > li::before {
		width: 0.35em;
		height: 0.35em;
		top: calc(0.9em - 0.175em);
		left: 0.25em;
	}
	.lg\:gr-prose-xl > ul > li p {
		margin-top: 0.8em;
		margin-bottom: 0.8em;
	}
	.lg\:gr-prose-xl > ul > li > :first-child {
		margin-top: 1.2em;
	}
	.lg\:gr-prose-xl > ul > li > :last-child {
		margin-bottom: 1.2em;
	}
	.lg\:gr-prose-xl > ol > li > :first-child {
		margin-top: 1.2em;
	}
	.lg\:gr-prose-xl > ol > li > :last-child {
		margin-bottom: 1.2em;
	}
	.lg\:gr-prose-xl ol ol,
	.lg\:gr-prose-xl ol ul,
	.lg\:gr-prose-xl ul ol,
	.lg\:gr-prose-xl ul ul {
		margin-top: 0.8em;
		margin-bottom: 0.8em;
	}
	.lg\:gr-prose-xl hr {
		margin-top: 2.8em;
		margin-bottom: 2.8em;
	}
	.lg\:gr-prose-xl hr + * {
		margin-top: 0;
	}
	.lg\:gr-prose-xl h2 + * {
		margin-top: 0;
	}
	.lg\:gr-prose-xl h3 + * {
		margin-top: 0;
	}
	.lg\:gr-prose-xl h4 + * {
		margin-top: 0;
	}
	.lg\:gr-prose-xl table {
		font-size: 0.9em;
		line-height: 1.5555556;
	}
	.lg\:gr-prose-xl thead th {
		padding-right: 0.6666667em;
		padding-bottom: 0.8888889em;
		padding-left: 0.6666667em;
	}
	.lg\:gr-prose-xl thead th:first-child {
		padding-left: 0;
	}
	.lg\:gr-prose-xl thead th:last-child {
		padding-right: 0;
	}
	.lg\:gr-prose-xl tbody td {
		padding-top: 0.8888889em;
		padding-right: 0.6666667em;
		padding-bottom: 0.8888889em;
		padding-left: 0.6666667em;
	}
	.lg\:gr-prose-xl tbody td:first-child {
		padding-left: 0;
	}
	.lg\:gr-prose-xl tbody td:last-child {
		padding-right: 0;
	}
	.lg\:gr-prose-xl > :first-child {
		margin-top: 0;
	}
	.lg\:gr-prose-xl > :last-child {
		margin-bottom: 0;
	}
	.lg\:gr-prose-2xl {
		font-size: 1.5rem;
		line-height: 1.6666667;
	}
	.lg\:gr-prose-2xl p {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.lg\:gr-prose-2xl [class~="lead"] {
		font-size: 1.25em;
		line-height: 1.4666667;
		margin-top: 1.0666667em;
		margin-bottom: 1.0666667em;
	}
	.lg\:gr-prose-2xl blockquote {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
		padding-left: 1.1111111em;
	}
	.lg\:gr-prose-2xl h1 {
		font-size: 2.6666667em;
		margin-top: 0;
		margin-bottom: 0.875em;
		line-height: 1;
	}
	.lg\:gr-prose-2xl h2 {
		font-size: 2em;
		margin-top: 1.5em;
		margin-bottom: 0.8333333em;
		line-height: 1.0833333;
	}
	.lg\:gr-prose-2xl h3 {
		font-size: 1.5em;
		margin-top: 1.5555556em;
		margin-bottom: 0.6666667em;
		line-height: 1.2222222;
	}
	.lg\:gr-prose-2xl h4 {
		margin-top: 1.6666667em;
		margin-bottom: 0.6666667em;
		line-height: 1.5;
	}
	.lg\:gr-prose-2xl img {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.lg\:gr-prose-2xl video {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.lg\:gr-prose-2xl figure {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.lg\:gr-prose-2xl figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.lg\:gr-prose-2xl figure figcaption {
		font-size: 0.8333333em;
		line-height: 1.6;
		margin-top: 1em;
	}
	.lg\:gr-prose-2xl code {
		font-size: 0.8333333em;
	}
	.lg\:gr-prose-2xl h2 code {
		font-size: 0.875em;
	}
	.lg\:gr-prose-2xl h3 code {
		font-size: 0.8888889em;
	}
	.lg\:gr-prose-2xl pre {
		font-size: 0.8333333em;
		line-height: 1.8;
		margin-top: 2em;
		margin-bottom: 2em;
		border-radius: 0.5rem;
		padding-top: 1.2em;
		padding-right: 1.6em;
		padding-bottom: 1.2em;
		padding-left: 1.6em;
	}
	.lg\:gr-prose-2xl ol {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.lg\:gr-prose-2xl ul {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.lg\:gr-prose-2xl li {
		margin-top: 0.5em;
		margin-bottom: 0.5em;
	}
	.lg\:gr-prose-2xl ol > li {
		padding-left: 1.6666667em;
	}
	.lg\:gr-prose-2xl ol > li::before {
		left: 0;
	}
	.lg\:gr-prose-2xl ul > li {
		padding-left: 1.6666667em;
	}
	.lg\:gr-prose-2xl ul > li::before {
		width: 0.3333333em;
		height: 0.3333333em;
		top: calc(0.8333333em - 0.1666667em);
		left: 0.25em;
	}
	.lg\:gr-prose-2xl > ul > li p {
		margin-top: 0.8333333em;
		margin-bottom: 0.8333333em;
	}
	.lg\:gr-prose-2xl > ul > li > :first-child {
		margin-top: 1.3333333em;
	}
	.lg\:gr-prose-2xl > ul > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.lg\:gr-prose-2xl > ol > li > :first-child {
		margin-top: 1.3333333em;
	}
	.lg\:gr-prose-2xl > ol > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.lg\:gr-prose-2xl ol ol,
	.lg\:gr-prose-2xl ol ul,
	.lg\:gr-prose-2xl ul ol,
	.lg\:gr-prose-2xl ul ul {
		margin-top: 0.6666667em;
		margin-bottom: 0.6666667em;
	}
	.lg\:gr-prose-2xl hr {
		margin-top: 3em;
		margin-bottom: 3em;
	}
	.lg\:gr-prose-2xl hr + * {
		margin-top: 0;
	}
	.lg\:gr-prose-2xl h2 + * {
		margin-top: 0;
	}
	.lg\:gr-prose-2xl h3 + * {
		margin-top: 0;
	}
	.lg\:gr-prose-2xl h4 + * {
		margin-top: 0;
	}
	.lg\:gr-prose-2xl table {
		font-size: 0.8333333em;
		line-height: 1.4;
	}
	.lg\:gr-prose-2xl thead th {
		padding-right: 0.6em;
		padding-bottom: 0.8em;
		padding-left: 0.6em;
	}
	.lg\:gr-prose-2xl thead th:first-child {
		padding-left: 0;
	}
	.lg\:gr-prose-2xl thead th:last-child {
		padding-right: 0;
	}
	.lg\:gr-prose-2xl tbody td {
		padding-top: 0.8em;
		padding-right: 0.6em;
		padding-bottom: 0.8em;
		padding-left: 0.6em;
	}
	.lg\:gr-prose-2xl tbody td:first-child {
		padding-left: 0;
	}
	.lg\:gr-prose-2xl tbody td:last-child {
		padding-right: 0;
	}
	.lg\:gr-prose-2xl > :first-child {
		margin-top: 0;
	}
	.lg\:gr-prose-2xl > :last-child {
		margin-bottom: 0;
	}
	.lg\:gr-prose-red a {
		color: #dc2626;
	}
	.lg\:gr-prose-red a code {
		color: #dc2626;
	}
	.lg\:gr-prose-yellow a {
		color: #d97706;
	}
	.lg\:gr-prose-yellow a code {
		color: #d97706;
	}
	.lg\:gr-prose-green a {
		color: #059669;
	}
	.lg\:gr-prose-green a code {
		color: #059669;
	}
	.lg\:gr-prose-blue a {
		color: #2563eb;
	}
	.lg\:gr-prose-blue a code {
		color: #2563eb;
	}
	.lg\:gr-prose-indigo a {
		color: #4f46e5;
	}
	.lg\:gr-prose-indigo a code {
		color: #4f46e5;
	}
	.lg\:gr-prose-purple a {
		color: #7c3aed;
	}
	.lg\:gr-prose-purple a code {
		color: #7c3aed;
	}
	.lg\:gr-prose-pink a {
		color: #db2777;
	}
	.lg\:gr-prose-pink a code {
		color: #db2777;
	}
}
@media (min-width: 1280px) {
	.xl\:gr-prose {
		color: #374151;
		max-width: 65ch;
	}
	.xl\:gr-prose [class~="lead"] {
		color: #4b5563;
		font-size: 1.25em;
		line-height: 1.6;
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.xl\:gr-prose a {
		color: #111827;
		text-decoration: underline;
		font-weight: 500;
	}
	.xl\:gr-prose strong {
		color: #111827;
		font-weight: 600;
	}
	.xl\:gr-prose ol[type="A"] {
		--list-counter-style: upper-alpha;
	}
	.xl\:gr-prose ol[type="a"] {
		--list-counter-style: lower-alpha;
	}
	.xl\:gr-prose ol[type="A"s] {
		--list-counter-style: upper-alpha;
	}
	.xl\:gr-prose ol[type="a"s] {
		--list-counter-style: lower-alpha;
	}
	.xl\:gr-prose ol[type="I"] {
		--list-counter-style: upper-roman;
	}
	.xl\:gr-prose ol[type="i"] {
		--list-counter-style: lower-roman;
	}
	.xl\:gr-prose ol[type="I"s] {
		--list-counter-style: upper-roman;
	}
	.xl\:gr-prose ol[type="i"s] {
		--list-counter-style: lower-roman;
	}
	.xl\:gr-prose ol[type="1"] {
		--list-counter-style: decimal;
	}
	.xl\:gr-prose ol > li {
		position: relative;
		padding-left: 1.75em;
	}
	.xl\:gr-prose ol > li::before {
		content: counter(list-item, var(--list-counter-style, decimal)) ".";
		position: absolute;
		font-weight: 400;
		color: #6b7280;
		left: 0;
	}
	.xl\:gr-prose ul > li {
		position: relative;
		padding-left: 1.75em;
	}
	.xl\:gr-prose ul > li::before {
		content: "";
		position: absolute;
		background-color: #d1d5db;
		border-radius: 50%;
		width: 0.375em;
		height: 0.375em;
		top: calc(0.875em - 0.1875em);
		left: 0.25em;
	}
	.xl\:gr-prose hr {
		border-color: #e5e7eb;
		border-top-width: 1px;
		margin-top: 3em;
		margin-bottom: 3em;
	}
	.xl\:gr-prose blockquote {
		font-weight: 500;
		font-style: italic;
		color: #111827;
		border-left-width: 0.25rem;
		border-left-color: #e5e7eb;
		quotes: "\201C""\201D""\2018""\2019";
		margin-top: 1.6em;
		margin-bottom: 1.6em;
		padding-left: 1em;
	}
	.xl\:gr-prose blockquote p:first-of-type::before {
		content: open-quote;
	}
	.xl\:gr-prose blockquote p:last-of-type::after {
		content: close-quote;
	}
	.xl\:gr-prose h1 {
		color: #111827;
		font-weight: 600;
		font-size: 2.25em;
		margin-top: 0;
		margin-bottom: 0.8888889em;
		line-height: 1.1111111;
	}
	.xl\:gr-prose h2 {
		color: #111827;
		font-weight: 600;
		font-size: 1.5em;
		margin-top: 2em;
		margin-bottom: 1em;
		line-height: 1.3333333;
	}
	.xl\:gr-prose h3 {
		color: #111827;
		font-weight: 600;
		font-size: 1.25em;
		margin-top: 1.6em;
		margin-bottom: 0.6em;
		line-height: 1.6;
	}
	.xl\:gr-prose h4 {
		color: #111827;
		font-weight: 600;
		margin-top: 1.5em;
		margin-bottom: 0.5em;
		line-height: 1.5;
	}
	.xl\:gr-prose figure figcaption {
		color: #6b7280;
		font-size: 0.875em;
		line-height: 1.4285714;
		margin-top: 0.8571429em;
	}
	.xl\:gr-prose code {
		color: #111827;
		font-weight: 600;
		font-size: 0.875em;
	}
	.xl\:gr-prose code::before {
		content: "`";
	}
	.xl\:gr-prose code::after {
		content: "`";
	}
	.xl\:gr-prose a code {
		color: #111827;
	}
	.xl\:gr-prose pre {
		color: #e5e7eb;
		background-color: #1f2937;
		overflow-x: auto;
		font-size: 0.875em;
		line-height: 1.7142857;
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
		border-radius: 0.375rem;
		padding-top: 0.8571429em;
		padding-right: 1.1428571em;
		padding-bottom: 0.8571429em;
		padding-left: 1.1428571em;
	}
	.xl\:gr-prose pre code {
		background-color: transparent;
		border-width: 0;
		border-radius: 0;
		padding: 0;
		font-weight: 400;
		color: inherit;
		font-size: inherit;
		font-family: inherit;
		line-height: inherit;
	}
	.xl\:gr-prose pre code::before {
		content: none;
	}
	.xl\:gr-prose pre code::after {
		content: none;
	}
	.xl\:gr-prose table {
		width: 100%;
		table-layout: auto;
		text-align: left;
		margin-top: 2em;
		margin-bottom: 2em;
		font-size: 0.875em;
		line-height: 1.7142857;
	}
	.xl\:gr-prose thead {
		color: #111827;
		font-weight: 600;
		border-bottom-width: 1px;
		border-bottom-color: #d1d5db;
	}
	.xl\:gr-prose thead th {
		vertical-align: bottom;
		padding-right: 0.5714286em;
		padding-bottom: 0.5714286em;
		padding-left: 0.5714286em;
	}
	.xl\:gr-prose tbody tr {
		border-bottom-width: 1px;
		border-bottom-color: #e5e7eb;
	}
	.xl\:gr-prose tbody tr:last-child {
		border-bottom-width: 0;
	}
	.xl\:gr-prose tbody td {
		vertical-align: top;
		padding-top: 0.5714286em;
		padding-right: 0.5714286em;
		padding-bottom: 0.5714286em;
		padding-left: 0.5714286em;
	}
	.xl\:gr-prose {
		font-size: 1rem;
		line-height: 1.75;
	}
	.xl\:gr-prose p {
		margin-top: 1.25em;
		margin-bottom: 1.25em;
	}
	.xl\:gr-prose img {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.xl\:gr-prose video {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.xl\:gr-prose figure {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.xl\:gr-prose figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.xl\:gr-prose h2 code {
		font-size: 0.875em;
	}
	.xl\:gr-prose h3 code {
		font-size: 0.9em;
	}
	.xl\:gr-prose ol {
		margin-top: 1.25em;
		margin-bottom: 1.25em;
	}
	.xl\:gr-prose ul {
		margin-top: 1.25em;
		margin-bottom: 1.25em;
	}
	.xl\:gr-prose li {
		margin-top: 0.5em;
		margin-bottom: 0.5em;
	}
	.xl\:gr-prose > ul > li p {
		margin-top: 0.75em;
		margin-bottom: 0.75em;
	}
	.xl\:gr-prose > ul > li > :first-child {
		margin-top: 1.25em;
	}
	.xl\:gr-prose > ul > li > :last-child {
		margin-bottom: 1.25em;
	}
	.xl\:gr-prose > ol > li > :first-child {
		margin-top: 1.25em;
	}
	.xl\:gr-prose > ol > li > :last-child {
		margin-bottom: 1.25em;
	}
	.xl\:gr-prose ol ol,
	.xl\:gr-prose ol ul,
	.xl\:gr-prose ul ol,
	.xl\:gr-prose ul ul {
		margin-top: 0.75em;
		margin-bottom: 0.75em;
	}
	.xl\:gr-prose hr + * {
		margin-top: 0;
	}
	.xl\:gr-prose h2 + * {
		margin-top: 0;
	}
	.xl\:gr-prose h3 + * {
		margin-top: 0;
	}
	.xl\:gr-prose h4 + * {
		margin-top: 0;
	}
	.xl\:gr-prose thead th:first-child {
		padding-left: 0;
	}
	.xl\:gr-prose thead th:last-child {
		padding-right: 0;
	}
	.xl\:gr-prose tbody td:first-child {
		padding-left: 0;
	}
	.xl\:gr-prose tbody td:last-child {
		padding-right: 0;
	}
	.xl\:gr-prose > :first-child {
		margin-top: 0;
	}
	.xl\:gr-prose > :last-child {
		margin-bottom: 0;
	}
	.xl\:gr-prose-sm {
		font-size: 0.875rem;
		line-height: 1.7142857;
	}
	.xl\:gr-prose-sm p {
		margin-top: 1.1428571em;
		margin-bottom: 1.1428571em;
	}
	.xl\:gr-prose-sm [class~="lead"] {
		font-size: 1.2857143em;
		line-height: 1.5555556;
		margin-top: 0.8888889em;
		margin-bottom: 0.8888889em;
	}
	.xl\:gr-prose-sm blockquote {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
		padding-left: 1.1111111em;
	}
	.xl\:gr-prose-sm h1 {
		font-size: 2.1428571em;
		margin-top: 0;
		margin-bottom: 0.8em;
		line-height: 1.2;
	}
	.xl\:gr-prose-sm h2 {
		font-size: 1.4285714em;
		margin-top: 1.6em;
		margin-bottom: 0.8em;
		line-height: 1.4;
	}
	.xl\:gr-prose-sm h3 {
		font-size: 1.2857143em;
		margin-top: 1.5555556em;
		margin-bottom: 0.4444444em;
		line-height: 1.5555556;
	}
	.xl\:gr-prose-sm h4 {
		margin-top: 1.4285714em;
		margin-bottom: 0.5714286em;
		line-height: 1.4285714;
	}
	.xl\:gr-prose-sm img {
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
	}
	.xl\:gr-prose-sm video {
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
	}
	.xl\:gr-prose-sm figure {
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
	}
	.xl\:gr-prose-sm figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.xl\:gr-prose-sm figure figcaption {
		font-size: 0.8571429em;
		line-height: 1.3333333;
		margin-top: 0.6666667em;
	}
	.xl\:gr-prose-sm code {
		font-size: 0.8571429em;
	}
	.xl\:gr-prose-sm h2 code {
		font-size: 0.9em;
	}
	.xl\:gr-prose-sm h3 code {
		font-size: 0.8888889em;
	}
	.xl\:gr-prose-sm pre {
		font-size: 0.8571429em;
		line-height: 1.6666667;
		margin-top: 1.6666667em;
		margin-bottom: 1.6666667em;
		border-radius: 0.25rem;
		padding-top: 0.6666667em;
		padding-right: 1em;
		padding-bottom: 0.6666667em;
		padding-left: 1em;
	}
	.xl\:gr-prose-sm ol {
		margin-top: 1.1428571em;
		margin-bottom: 1.1428571em;
	}
	.xl\:gr-prose-sm ul {
		margin-top: 1.1428571em;
		margin-bottom: 1.1428571em;
	}
	.xl\:gr-prose-sm li {
		margin-top: 0.2857143em;
		margin-bottom: 0.2857143em;
	}
	.xl\:gr-prose-sm ol > li {
		padding-left: 1.5714286em;
	}
	.xl\:gr-prose-sm ol > li::before {
		left: 0;
	}
	.xl\:gr-prose-sm ul > li {
		padding-left: 1.5714286em;
	}
	.xl\:gr-prose-sm ul > li::before {
		height: 0.3571429em;
		width: 0.3571429em;
		top: calc(0.8571429em - 0.1785714em);
		left: 0.2142857em;
	}
	.xl\:gr-prose-sm > ul > li p {
		margin-top: 0.5714286em;
		margin-bottom: 0.5714286em;
	}
	.xl\:gr-prose-sm > ul > li > :first-child {
		margin-top: 1.1428571em;
	}
	.xl\:gr-prose-sm > ul > li > :last-child {
		margin-bottom: 1.1428571em;
	}
	.xl\:gr-prose-sm > ol > li > :first-child {
		margin-top: 1.1428571em;
	}
	.xl\:gr-prose-sm > ol > li > :last-child {
		margin-bottom: 1.1428571em;
	}
	.xl\:gr-prose-sm ol ol,
	.xl\:gr-prose-sm ol ul,
	.xl\:gr-prose-sm ul ol,
	.xl\:gr-prose-sm ul ul {
		margin-top: 0.5714286em;
		margin-bottom: 0.5714286em;
	}
	.xl\:gr-prose-sm hr {
		margin-top: 2.8571429em;
		margin-bottom: 2.8571429em;
	}
	.xl\:gr-prose-sm hr + * {
		margin-top: 0;
	}
	.xl\:gr-prose-sm h2 + * {
		margin-top: 0;
	}
	.xl\:gr-prose-sm h3 + * {
		margin-top: 0;
	}
	.xl\:gr-prose-sm h4 + * {
		margin-top: 0;
	}
	.xl\:gr-prose-sm table {
		font-size: 0.8571429em;
		line-height: 1.5;
	}
	.xl\:gr-prose-sm thead th {
		padding-right: 1em;
		padding-bottom: 0.6666667em;
		padding-left: 1em;
	}
	.xl\:gr-prose-sm thead th:first-child {
		padding-left: 0;
	}
	.xl\:gr-prose-sm thead th:last-child {
		padding-right: 0;
	}
	.xl\:gr-prose-sm tbody td {
		padding-top: 0.6666667em;
		padding-right: 1em;
		padding-bottom: 0.6666667em;
		padding-left: 1em;
	}
	.xl\:gr-prose-sm tbody td:first-child {
		padding-left: 0;
	}
	.xl\:gr-prose-sm tbody td:last-child {
		padding-right: 0;
	}
	.xl\:gr-prose-sm > :first-child {
		margin-top: 0;
	}
	.xl\:gr-prose-sm > :last-child {
		margin-bottom: 0;
	}
	.xl\:gr-prose-lg {
		font-size: 1.125rem;
		line-height: 1.7777778;
	}
	.xl\:gr-prose-lg p {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.xl\:gr-prose-lg [class~="lead"] {
		font-size: 1.2222222em;
		line-height: 1.4545455;
		margin-top: 1.0909091em;
		margin-bottom: 1.0909091em;
	}
	.xl\:gr-prose-lg blockquote {
		margin-top: 1.6666667em;
		margin-bottom: 1.6666667em;
		padding-left: 1em;
	}
	.xl\:gr-prose-lg h1 {
		font-size: 2.6666667em;
		margin-top: 0;
		margin-bottom: 0.8333333em;
		line-height: 1;
	}
	.xl\:gr-prose-lg h2 {
		font-size: 1.6666667em;
		margin-top: 1.8666667em;
		margin-bottom: 1.0666667em;
		line-height: 1.3333333;
	}
	.xl\:gr-prose-lg h3 {
		font-size: 1.3333333em;
		margin-top: 1.6666667em;
		margin-bottom: 0.6666667em;
		line-height: 1.5;
	}
	.xl\:gr-prose-lg h4 {
		margin-top: 1.7777778em;
		margin-bottom: 0.4444444em;
		line-height: 1.5555556;
	}
	.xl\:gr-prose-lg img {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
	}
	.xl\:gr-prose-lg video {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
	}
	.xl\:gr-prose-lg figure {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
	}
	.xl\:gr-prose-lg figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.xl\:gr-prose-lg figure figcaption {
		font-size: 0.8888889em;
		line-height: 1.5;
		margin-top: 1em;
	}
	.xl\:gr-prose-lg code {
		font-size: 0.8888889em;
	}
	.xl\:gr-prose-lg h2 code {
		font-size: 0.8666667em;
	}
	.xl\:gr-prose-lg h3 code {
		font-size: 0.875em;
	}
	.xl\:gr-prose-lg pre {
		font-size: 0.8888889em;
		line-height: 1.75;
		margin-top: 2em;
		margin-bottom: 2em;
		border-radius: 0.375rem;
		padding-top: 1em;
		padding-right: 1.5em;
		padding-bottom: 1em;
		padding-left: 1.5em;
	}
	.xl\:gr-prose-lg ol {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.xl\:gr-prose-lg ul {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.xl\:gr-prose-lg li {
		margin-top: 0.6666667em;
		margin-bottom: 0.6666667em;
	}
	.xl\:gr-prose-lg ol > li {
		padding-left: 1.6666667em;
	}
	.xl\:gr-prose-lg ol > li::before {
		left: 0;
	}
	.xl\:gr-prose-lg ul > li {
		padding-left: 1.6666667em;
	}
	.xl\:gr-prose-lg ul > li::before {
		width: 0.3333333em;
		height: 0.3333333em;
		top: calc(0.8888889em - 0.1666667em);
		left: 0.2222222em;
	}
	.xl\:gr-prose-lg > ul > li p {
		margin-top: 0.8888889em;
		margin-bottom: 0.8888889em;
	}
	.xl\:gr-prose-lg > ul > li > :first-child {
		margin-top: 1.3333333em;
	}
	.xl\:gr-prose-lg > ul > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.xl\:gr-prose-lg > ol > li > :first-child {
		margin-top: 1.3333333em;
	}
	.xl\:gr-prose-lg > ol > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.xl\:gr-prose-lg ol ol,
	.xl\:gr-prose-lg ol ul,
	.xl\:gr-prose-lg ul ol,
	.xl\:gr-prose-lg ul ul {
		margin-top: 0.8888889em;
		margin-bottom: 0.8888889em;
	}
	.xl\:gr-prose-lg hr {
		margin-top: 3.1111111em;
		margin-bottom: 3.1111111em;
	}
	.xl\:gr-prose-lg hr + * {
		margin-top: 0;
	}
	.xl\:gr-prose-lg h2 + * {
		margin-top: 0;
	}
	.xl\:gr-prose-lg h3 + * {
		margin-top: 0;
	}
	.xl\:gr-prose-lg h4 + * {
		margin-top: 0;
	}
	.xl\:gr-prose-lg table {
		font-size: 0.8888889em;
		line-height: 1.5;
	}
	.xl\:gr-prose-lg thead th {
		padding-right: 0.75em;
		padding-bottom: 0.75em;
		padding-left: 0.75em;
	}
	.xl\:gr-prose-lg thead th:first-child {
		padding-left: 0;
	}
	.xl\:gr-prose-lg thead th:last-child {
		padding-right: 0;
	}
	.xl\:gr-prose-lg tbody td {
		padding-top: 0.75em;
		padding-right: 0.75em;
		padding-bottom: 0.75em;
		padding-left: 0.75em;
	}
	.xl\:gr-prose-lg tbody td:first-child {
		padding-left: 0;
	}
	.xl\:gr-prose-lg tbody td:last-child {
		padding-right: 0;
	}
	.xl\:gr-prose-lg > :first-child {
		margin-top: 0;
	}
	.xl\:gr-prose-lg > :last-child {
		margin-bottom: 0;
	}
	.xl\:gr-prose-xl {
		font-size: 1.25rem;
		line-height: 1.8;
	}
	.xl\:gr-prose-xl p {
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.xl\:gr-prose-xl [class~="lead"] {
		font-size: 1.2em;
		line-height: 1.5;
		margin-top: 1em;
		margin-bottom: 1em;
	}
	.xl\:gr-prose-xl blockquote {
		margin-top: 1.6em;
		margin-bottom: 1.6em;
		padding-left: 1.0666667em;
	}
	.xl\:gr-prose-xl h1 {
		font-size: 2.8em;
		margin-top: 0;
		margin-bottom: 0.8571429em;
		line-height: 1;
	}
	.xl\:gr-prose-xl h2 {
		font-size: 1.8em;
		margin-top: 1.5555556em;
		margin-bottom: 0.8888889em;
		line-height: 1.1111111;
	}
	.xl\:gr-prose-xl h3 {
		font-size: 1.5em;
		margin-top: 1.6em;
		margin-bottom: 0.6666667em;
		line-height: 1.3333333;
	}
	.xl\:gr-prose-xl h4 {
		margin-top: 1.8em;
		margin-bottom: 0.6em;
		line-height: 1.6;
	}
	.xl\:gr-prose-xl img {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.xl\:gr-prose-xl video {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.xl\:gr-prose-xl figure {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.xl\:gr-prose-xl figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.xl\:gr-prose-xl figure figcaption {
		font-size: 0.9em;
		line-height: 1.5555556;
		margin-top: 1em;
	}
	.xl\:gr-prose-xl code {
		font-size: 0.9em;
	}
	.xl\:gr-prose-xl h2 code {
		font-size: 0.8611111em;
	}
	.xl\:gr-prose-xl h3 code {
		font-size: 0.9em;
	}
	.xl\:gr-prose-xl pre {
		font-size: 0.9em;
		line-height: 1.7777778;
		margin-top: 2em;
		margin-bottom: 2em;
		border-radius: 0.5rem;
		padding-top: 1.1111111em;
		padding-right: 1.3333333em;
		padding-bottom: 1.1111111em;
		padding-left: 1.3333333em;
	}
	.xl\:gr-prose-xl ol {
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.xl\:gr-prose-xl ul {
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.xl\:gr-prose-xl li {
		margin-top: 0.6em;
		margin-bottom: 0.6em;
	}
	.xl\:gr-prose-xl ol > li {
		padding-left: 1.8em;
	}
	.xl\:gr-prose-xl ol > li::before {
		left: 0;
	}
	.xl\:gr-prose-xl ul > li {
		padding-left: 1.8em;
	}
	.xl\:gr-prose-xl ul > li::before {
		width: 0.35em;
		height: 0.35em;
		top: calc(0.9em - 0.175em);
		left: 0.25em;
	}
	.xl\:gr-prose-xl > ul > li p {
		margin-top: 0.8em;
		margin-bottom: 0.8em;
	}
	.xl\:gr-prose-xl > ul > li > :first-child {
		margin-top: 1.2em;
	}
	.xl\:gr-prose-xl > ul > li > :last-child {
		margin-bottom: 1.2em;
	}
	.xl\:gr-prose-xl > ol > li > :first-child {
		margin-top: 1.2em;
	}
	.xl\:gr-prose-xl > ol > li > :last-child {
		margin-bottom: 1.2em;
	}
	.xl\:gr-prose-xl ol ol,
	.xl\:gr-prose-xl ol ul,
	.xl\:gr-prose-xl ul ol,
	.xl\:gr-prose-xl ul ul {
		margin-top: 0.8em;
		margin-bottom: 0.8em;
	}
	.xl\:gr-prose-xl hr {
		margin-top: 2.8em;
		margin-bottom: 2.8em;
	}
	.xl\:gr-prose-xl hr + * {
		margin-top: 0;
	}
	.xl\:gr-prose-xl h2 + * {
		margin-top: 0;
	}
	.xl\:gr-prose-xl h3 + * {
		margin-top: 0;
	}
	.xl\:gr-prose-xl h4 + * {
		margin-top: 0;
	}
	.xl\:gr-prose-xl table {
		font-size: 0.9em;
		line-height: 1.5555556;
	}
	.xl\:gr-prose-xl thead th {
		padding-right: 0.6666667em;
		padding-bottom: 0.8888889em;
		padding-left: 0.6666667em;
	}
	.xl\:gr-prose-xl thead th:first-child {
		padding-left: 0;
	}
	.xl\:gr-prose-xl thead th:last-child {
		padding-right: 0;
	}
	.xl\:gr-prose-xl tbody td {
		padding-top: 0.8888889em;
		padding-right: 0.6666667em;
		padding-bottom: 0.8888889em;
		padding-left: 0.6666667em;
	}
	.xl\:gr-prose-xl tbody td:first-child {
		padding-left: 0;
	}
	.xl\:gr-prose-xl tbody td:last-child {
		padding-right: 0;
	}
	.xl\:gr-prose-xl > :first-child {
		margin-top: 0;
	}
	.xl\:gr-prose-xl > :last-child {
		margin-bottom: 0;
	}
	.xl\:gr-prose-2xl {
		font-size: 1.5rem;
		line-height: 1.6666667;
	}
	.xl\:gr-prose-2xl p {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.xl\:gr-prose-2xl [class~="lead"] {
		font-size: 1.25em;
		line-height: 1.4666667;
		margin-top: 1.0666667em;
		margin-bottom: 1.0666667em;
	}
	.xl\:gr-prose-2xl blockquote {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
		padding-left: 1.1111111em;
	}
	.xl\:gr-prose-2xl h1 {
		font-size: 2.6666667em;
		margin-top: 0;
		margin-bottom: 0.875em;
		line-height: 1;
	}
	.xl\:gr-prose-2xl h2 {
		font-size: 2em;
		margin-top: 1.5em;
		margin-bottom: 0.8333333em;
		line-height: 1.0833333;
	}
	.xl\:gr-prose-2xl h3 {
		font-size: 1.5em;
		margin-top: 1.5555556em;
		margin-bottom: 0.6666667em;
		line-height: 1.2222222;
	}
	.xl\:gr-prose-2xl h4 {
		margin-top: 1.6666667em;
		margin-bottom: 0.6666667em;
		line-height: 1.5;
	}
	.xl\:gr-prose-2xl img {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.xl\:gr-prose-2xl video {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.xl\:gr-prose-2xl figure {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.xl\:gr-prose-2xl figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.xl\:gr-prose-2xl figure figcaption {
		font-size: 0.8333333em;
		line-height: 1.6;
		margin-top: 1em;
	}
	.xl\:gr-prose-2xl code {
		font-size: 0.8333333em;
	}
	.xl\:gr-prose-2xl h2 code {
		font-size: 0.875em;
	}
	.xl\:gr-prose-2xl h3 code {
		font-size: 0.8888889em;
	}
	.xl\:gr-prose-2xl pre {
		font-size: 0.8333333em;
		line-height: 1.8;
		margin-top: 2em;
		margin-bottom: 2em;
		border-radius: 0.5rem;
		padding-top: 1.2em;
		padding-right: 1.6em;
		padding-bottom: 1.2em;
		padding-left: 1.6em;
	}
	.xl\:gr-prose-2xl ol {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.xl\:gr-prose-2xl ul {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.xl\:gr-prose-2xl li {
		margin-top: 0.5em;
		margin-bottom: 0.5em;
	}
	.xl\:gr-prose-2xl ol > li {
		padding-left: 1.6666667em;
	}
	.xl\:gr-prose-2xl ol > li::before {
		left: 0;
	}
	.xl\:gr-prose-2xl ul > li {
		padding-left: 1.6666667em;
	}
	.xl\:gr-prose-2xl ul > li::before {
		width: 0.3333333em;
		height: 0.3333333em;
		top: calc(0.8333333em - 0.1666667em);
		left: 0.25em;
	}
	.xl\:gr-prose-2xl > ul > li p {
		margin-top: 0.8333333em;
		margin-bottom: 0.8333333em;
	}
	.xl\:gr-prose-2xl > ul > li > :first-child {
		margin-top: 1.3333333em;
	}
	.xl\:gr-prose-2xl > ul > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.xl\:gr-prose-2xl > ol > li > :first-child {
		margin-top: 1.3333333em;
	}
	.xl\:gr-prose-2xl > ol > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.xl\:gr-prose-2xl ol ol,
	.xl\:gr-prose-2xl ol ul,
	.xl\:gr-prose-2xl ul ol,
	.xl\:gr-prose-2xl ul ul {
		margin-top: 0.6666667em;
		margin-bottom: 0.6666667em;
	}
	.xl\:gr-prose-2xl hr {
		margin-top: 3em;
		margin-bottom: 3em;
	}
	.xl\:gr-prose-2xl hr + * {
		margin-top: 0;
	}
	.xl\:gr-prose-2xl h2 + * {
		margin-top: 0;
	}
	.xl\:gr-prose-2xl h3 + * {
		margin-top: 0;
	}
	.xl\:gr-prose-2xl h4 + * {
		margin-top: 0;
	}
	.xl\:gr-prose-2xl table {
		font-size: 0.8333333em;
		line-height: 1.4;
	}
	.xl\:gr-prose-2xl thead th {
		padding-right: 0.6em;
		padding-bottom: 0.8em;
		padding-left: 0.6em;
	}
	.xl\:gr-prose-2xl thead th:first-child {
		padding-left: 0;
	}
	.xl\:gr-prose-2xl thead th:last-child {
		padding-right: 0;
	}
	.xl\:gr-prose-2xl tbody td {
		padding-top: 0.8em;
		padding-right: 0.6em;
		padding-bottom: 0.8em;
		padding-left: 0.6em;
	}
	.xl\:gr-prose-2xl tbody td:first-child {
		padding-left: 0;
	}
	.xl\:gr-prose-2xl tbody td:last-child {
		padding-right: 0;
	}
	.xl\:gr-prose-2xl > :first-child {
		margin-top: 0;
	}
	.xl\:gr-prose-2xl > :last-child {
		margin-bottom: 0;
	}
	.xl\:gr-prose-red a {
		color: #dc2626;
	}
	.xl\:gr-prose-red a code {
		color: #dc2626;
	}
	.xl\:gr-prose-yellow a {
		color: #d97706;
	}
	.xl\:gr-prose-yellow a code {
		color: #d97706;
	}
	.xl\:gr-prose-green a {
		color: #059669;
	}
	.xl\:gr-prose-green a code {
		color: #059669;
	}
	.xl\:gr-prose-blue a {
		color: #2563eb;
	}
	.xl\:gr-prose-blue a code {
		color: #2563eb;
	}
	.xl\:gr-prose-indigo a {
		color: #4f46e5;
	}
	.xl\:gr-prose-indigo a code {
		color: #4f46e5;
	}
	.xl\:gr-prose-purple a {
		color: #7c3aed;
	}
	.xl\:gr-prose-purple a code {
		color: #7c3aed;
	}
	.xl\:gr-prose-pink a {
		color: #db2777;
	}
	.xl\:gr-prose-pink a code {
		color: #db2777;
	}
}
@media (min-width: 1536px) {
	.\32xl\:gr-prose {
		color: #374151;
		max-width: 65ch;
	}
	.\32xl\:gr-prose [class~="lead"] {
		color: #4b5563;
		font-size: 1.25em;
		line-height: 1.6;
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.\32xl\:gr-prose a {
		color: #111827;
		text-decoration: underline;
		font-weight: 500;
	}
	.\32xl\:gr-prose strong {
		color: #111827;
		font-weight: 600;
	}
	.\32xl\:gr-prose ol[type="A"] {
		--list-counter-style: upper-alpha;
	}
	.\32xl\:gr-prose ol[type="a"] {
		--list-counter-style: lower-alpha;
	}
	.\32xl\:gr-prose ol[type="A"s] {
		--list-counter-style: upper-alpha;
	}
	.\32xl\:gr-prose ol[type="a"s] {
		--list-counter-style: lower-alpha;
	}
	.\32xl\:gr-prose ol[type="I"] {
		--list-counter-style: upper-roman;
	}
	.\32xl\:gr-prose ol[type="i"] {
		--list-counter-style: lower-roman;
	}
	.\32xl\:gr-prose ol[type="I"s] {
		--list-counter-style: upper-roman;
	}
	.\32xl\:gr-prose ol[type="i"s] {
		--list-counter-style: lower-roman;
	}
	.\32xl\:gr-prose ol[type="1"] {
		--list-counter-style: decimal;
	}
	.\32xl\:gr-prose ol > li {
		position: relative;
		padding-left: 1.75em;
	}
	.\32xl\:gr-prose ol > li::before {
		content: counter(list-item, var(--list-counter-style, decimal)) ".";
		position: absolute;
		font-weight: 400;
		color: #6b7280;
		left: 0;
	}
	.\32xl\:gr-prose ul > li {
		position: relative;
		padding-left: 1.75em;
	}
	.\32xl\:gr-prose ul > li::before {
		content: "";
		position: absolute;
		background-color: #d1d5db;
		border-radius: 50%;
		width: 0.375em;
		height: 0.375em;
		top: calc(0.875em - 0.1875em);
		left: 0.25em;
	}
	.\32xl\:gr-prose hr {
		border-color: #e5e7eb;
		border-top-width: 1px;
		margin-top: 3em;
		margin-bottom: 3em;
	}
	.\32xl\:gr-prose blockquote {
		font-weight: 500;
		font-style: italic;
		color: #111827;
		border-left-width: 0.25rem;
		border-left-color: #e5e7eb;
		quotes: "\201C""\201D""\2018""\2019";
		margin-top: 1.6em;
		margin-bottom: 1.6em;
		padding-left: 1em;
	}
	.\32xl\:gr-prose blockquote p:first-of-type::before {
		content: open-quote;
	}
	.\32xl\:gr-prose blockquote p:last-of-type::after {
		content: close-quote;
	}
	.\32xl\:gr-prose h1 {
		color: #111827;
		font-weight: 600;
		font-size: 2.25em;
		margin-top: 0;
		margin-bottom: 0.8888889em;
		line-height: 1.1111111;
	}
	.\32xl\:gr-prose h2 {
		color: #111827;
		font-weight: 600;
		font-size: 1.5em;
		margin-top: 2em;
		margin-bottom: 1em;
		line-height: 1.3333333;
	}
	.\32xl\:gr-prose h3 {
		color: #111827;
		font-weight: 600;
		font-size: 1.25em;
		margin-top: 1.6em;
		margin-bottom: 0.6em;
		line-height: 1.6;
	}
	.\32xl\:gr-prose h4 {
		color: #111827;
		font-weight: 600;
		margin-top: 1.5em;
		margin-bottom: 0.5em;
		line-height: 1.5;
	}
	.\32xl\:gr-prose figure figcaption {
		color: #6b7280;
		font-size: 0.875em;
		line-height: 1.4285714;
		margin-top: 0.8571429em;
	}
	.\32xl\:gr-prose code {
		color: #111827;
		font-weight: 600;
		font-size: 0.875em;
	}
	.\32xl\:gr-prose code::before {
		content: "`";
	}
	.\32xl\:gr-prose code::after {
		content: "`";
	}
	.\32xl\:gr-prose a code {
		color: #111827;
	}
	.\32xl\:gr-prose pre {
		color: #e5e7eb;
		background-color: #1f2937;
		overflow-x: auto;
		font-size: 0.875em;
		line-height: 1.7142857;
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
		border-radius: 0.375rem;
		padding-top: 0.8571429em;
		padding-right: 1.1428571em;
		padding-bottom: 0.8571429em;
		padding-left: 1.1428571em;
	}
	.\32xl\:gr-prose pre code {
		background-color: transparent;
		border-width: 0;
		border-radius: 0;
		padding: 0;
		font-weight: 400;
		color: inherit;
		font-size: inherit;
		font-family: inherit;
		line-height: inherit;
	}
	.\32xl\:gr-prose pre code::before {
		content: none;
	}
	.\32xl\:gr-prose pre code::after {
		content: none;
	}
	.\32xl\:gr-prose table {
		width: 100%;
		table-layout: auto;
		text-align: left;
		margin-top: 2em;
		margin-bottom: 2em;
		font-size: 0.875em;
		line-height: 1.7142857;
	}
	.\32xl\:gr-prose thead {
		color: #111827;
		font-weight: 600;
		border-bottom-width: 1px;
		border-bottom-color: #d1d5db;
	}
	.\32xl\:gr-prose thead th {
		vertical-align: bottom;
		padding-right: 0.5714286em;
		padding-bottom: 0.5714286em;
		padding-left: 0.5714286em;
	}
	.\32xl\:gr-prose tbody tr {
		border-bottom-width: 1px;
		border-bottom-color: #e5e7eb;
	}
	.\32xl\:gr-prose tbody tr:last-child {
		border-bottom-width: 0;
	}
	.\32xl\:gr-prose tbody td {
		vertical-align: top;
		padding-top: 0.5714286em;
		padding-right: 0.5714286em;
		padding-bottom: 0.5714286em;
		padding-left: 0.5714286em;
	}
	.\32xl\:gr-prose {
		font-size: 1rem;
		line-height: 1.75;
	}
	.\32xl\:gr-prose p {
		margin-top: 1.25em;
		margin-bottom: 1.25em;
	}
	.\32xl\:gr-prose img {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.\32xl\:gr-prose video {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.\32xl\:gr-prose figure {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.\32xl\:gr-prose figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.\32xl\:gr-prose h2 code {
		font-size: 0.875em;
	}
	.\32xl\:gr-prose h3 code {
		font-size: 0.9em;
	}
	.\32xl\:gr-prose ol {
		margin-top: 1.25em;
		margin-bottom: 1.25em;
	}
	.\32xl\:gr-prose ul {
		margin-top: 1.25em;
		margin-bottom: 1.25em;
	}
	.\32xl\:gr-prose li {
		margin-top: 0.5em;
		margin-bottom: 0.5em;
	}
	.\32xl\:gr-prose > ul > li p {
		margin-top: 0.75em;
		margin-bottom: 0.75em;
	}
	.\32xl\:gr-prose > ul > li > :first-child {
		margin-top: 1.25em;
	}
	.\32xl\:gr-prose > ul > li > :last-child {
		margin-bottom: 1.25em;
	}
	.\32xl\:gr-prose > ol > li > :first-child {
		margin-top: 1.25em;
	}
	.\32xl\:gr-prose > ol > li > :last-child {
		margin-bottom: 1.25em;
	}
	.\32xl\:gr-prose ol ol,
	.\32xl\:gr-prose ol ul,
	.\32xl\:gr-prose ul ol,
	.\32xl\:gr-prose ul ul {
		margin-top: 0.75em;
		margin-bottom: 0.75em;
	}
	.\32xl\:gr-prose hr + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose h2 + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose h3 + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose h4 + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose thead th:first-child {
		padding-left: 0;
	}
	.\32xl\:gr-prose thead th:last-child {
		padding-right: 0;
	}
	.\32xl\:gr-prose tbody td:first-child {
		padding-left: 0;
	}
	.\32xl\:gr-prose tbody td:last-child {
		padding-right: 0;
	}
	.\32xl\:gr-prose > :first-child {
		margin-top: 0;
	}
	.\32xl\:gr-prose > :last-child {
		margin-bottom: 0;
	}
	.\32xl\:gr-prose-sm {
		font-size: 0.875rem;
		line-height: 1.7142857;
	}
	.\32xl\:gr-prose-sm p {
		margin-top: 1.1428571em;
		margin-bottom: 1.1428571em;
	}
	.\32xl\:gr-prose-sm [class~="lead"] {
		font-size: 1.2857143em;
		line-height: 1.5555556;
		margin-top: 0.8888889em;
		margin-bottom: 0.8888889em;
	}
	.\32xl\:gr-prose-sm blockquote {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
		padding-left: 1.1111111em;
	}
	.\32xl\:gr-prose-sm h1 {
		font-size: 2.1428571em;
		margin-top: 0;
		margin-bottom: 0.8em;
		line-height: 1.2;
	}
	.\32xl\:gr-prose-sm h2 {
		font-size: 1.4285714em;
		margin-top: 1.6em;
		margin-bottom: 0.8em;
		line-height: 1.4;
	}
	.\32xl\:gr-prose-sm h3 {
		font-size: 1.2857143em;
		margin-top: 1.5555556em;
		margin-bottom: 0.4444444em;
		line-height: 1.5555556;
	}
	.\32xl\:gr-prose-sm h4 {
		margin-top: 1.4285714em;
		margin-bottom: 0.5714286em;
		line-height: 1.4285714;
	}
	.\32xl\:gr-prose-sm img {
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
	}
	.\32xl\:gr-prose-sm video {
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
	}
	.\32xl\:gr-prose-sm figure {
		margin-top: 1.7142857em;
		margin-bottom: 1.7142857em;
	}
	.\32xl\:gr-prose-sm figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.\32xl\:gr-prose-sm figure figcaption {
		font-size: 0.8571429em;
		line-height: 1.3333333;
		margin-top: 0.6666667em;
	}
	.\32xl\:gr-prose-sm code {
		font-size: 0.8571429em;
	}
	.\32xl\:gr-prose-sm h2 code {
		font-size: 0.9em;
	}
	.\32xl\:gr-prose-sm h3 code {
		font-size: 0.8888889em;
	}
	.\32xl\:gr-prose-sm pre {
		font-size: 0.8571429em;
		line-height: 1.6666667;
		margin-top: 1.6666667em;
		margin-bottom: 1.6666667em;
		border-radius: 0.25rem;
		padding-top: 0.6666667em;
		padding-right: 1em;
		padding-bottom: 0.6666667em;
		padding-left: 1em;
	}
	.\32xl\:gr-prose-sm ol {
		margin-top: 1.1428571em;
		margin-bottom: 1.1428571em;
	}
	.\32xl\:gr-prose-sm ul {
		margin-top: 1.1428571em;
		margin-bottom: 1.1428571em;
	}
	.\32xl\:gr-prose-sm li {
		margin-top: 0.2857143em;
		margin-bottom: 0.2857143em;
	}
	.\32xl\:gr-prose-sm ol > li {
		padding-left: 1.5714286em;
	}
	.\32xl\:gr-prose-sm ol > li::before {
		left: 0;
	}
	.\32xl\:gr-prose-sm ul > li {
		padding-left: 1.5714286em;
	}
	.\32xl\:gr-prose-sm ul > li::before {
		height: 0.3571429em;
		width: 0.3571429em;
		top: calc(0.8571429em - 0.1785714em);
		left: 0.2142857em;
	}
	.\32xl\:gr-prose-sm > ul > li p {
		margin-top: 0.5714286em;
		margin-bottom: 0.5714286em;
	}
	.\32xl\:gr-prose-sm > ul > li > :first-child {
		margin-top: 1.1428571em;
	}
	.\32xl\:gr-prose-sm > ul > li > :last-child {
		margin-bottom: 1.1428571em;
	}
	.\32xl\:gr-prose-sm > ol > li > :first-child {
		margin-top: 1.1428571em;
	}
	.\32xl\:gr-prose-sm > ol > li > :last-child {
		margin-bottom: 1.1428571em;
	}
	.\32xl\:gr-prose-sm ol ol,
	.\32xl\:gr-prose-sm ol ul,
	.\32xl\:gr-prose-sm ul ol,
	.\32xl\:gr-prose-sm ul ul {
		margin-top: 0.5714286em;
		margin-bottom: 0.5714286em;
	}
	.\32xl\:gr-prose-sm hr {
		margin-top: 2.8571429em;
		margin-bottom: 2.8571429em;
	}
	.\32xl\:gr-prose-sm hr + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose-sm h2 + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose-sm h3 + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose-sm h4 + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose-sm table {
		font-size: 0.8571429em;
		line-height: 1.5;
	}
	.\32xl\:gr-prose-sm thead th {
		padding-right: 1em;
		padding-bottom: 0.6666667em;
		padding-left: 1em;
	}
	.\32xl\:gr-prose-sm thead th:first-child {
		padding-left: 0;
	}
	.\32xl\:gr-prose-sm thead th:last-child {
		padding-right: 0;
	}
	.\32xl\:gr-prose-sm tbody td {
		padding-top: 0.6666667em;
		padding-right: 1em;
		padding-bottom: 0.6666667em;
		padding-left: 1em;
	}
	.\32xl\:gr-prose-sm tbody td:first-child {
		padding-left: 0;
	}
	.\32xl\:gr-prose-sm tbody td:last-child {
		padding-right: 0;
	}
	.\32xl\:gr-prose-sm > :first-child {
		margin-top: 0;
	}
	.\32xl\:gr-prose-sm > :last-child {
		margin-bottom: 0;
	}
	.\32xl\:gr-prose-lg {
		font-size: 1.125rem;
		line-height: 1.7777778;
	}
	.\32xl\:gr-prose-lg p {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.\32xl\:gr-prose-lg [class~="lead"] {
		font-size: 1.2222222em;
		line-height: 1.4545455;
		margin-top: 1.0909091em;
		margin-bottom: 1.0909091em;
	}
	.\32xl\:gr-prose-lg blockquote {
		margin-top: 1.6666667em;
		margin-bottom: 1.6666667em;
		padding-left: 1em;
	}
	.\32xl\:gr-prose-lg h1 {
		font-size: 2.6666667em;
		margin-top: 0;
		margin-bottom: 0.8333333em;
		line-height: 1;
	}
	.\32xl\:gr-prose-lg h2 {
		font-size: 1.6666667em;
		margin-top: 1.8666667em;
		margin-bottom: 1.0666667em;
		line-height: 1.3333333;
	}
	.\32xl\:gr-prose-lg h3 {
		font-size: 1.3333333em;
		margin-top: 1.6666667em;
		margin-bottom: 0.6666667em;
		line-height: 1.5;
	}
	.\32xl\:gr-prose-lg h4 {
		margin-top: 1.7777778em;
		margin-bottom: 0.4444444em;
		line-height: 1.5555556;
	}
	.\32xl\:gr-prose-lg img {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
	}
	.\32xl\:gr-prose-lg video {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
	}
	.\32xl\:gr-prose-lg figure {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
	}
	.\32xl\:gr-prose-lg figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.\32xl\:gr-prose-lg figure figcaption {
		font-size: 0.8888889em;
		line-height: 1.5;
		margin-top: 1em;
	}
	.\32xl\:gr-prose-lg code {
		font-size: 0.8888889em;
	}
	.\32xl\:gr-prose-lg h2 code {
		font-size: 0.8666667em;
	}
	.\32xl\:gr-prose-lg h3 code {
		font-size: 0.875em;
	}
	.\32xl\:gr-prose-lg pre {
		font-size: 0.8888889em;
		line-height: 1.75;
		margin-top: 2em;
		margin-bottom: 2em;
		border-radius: 0.375rem;
		padding-top: 1em;
		padding-right: 1.5em;
		padding-bottom: 1em;
		padding-left: 1.5em;
	}
	.\32xl\:gr-prose-lg ol {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.\32xl\:gr-prose-lg ul {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.\32xl\:gr-prose-lg li {
		margin-top: 0.6666667em;
		margin-bottom: 0.6666667em;
	}
	.\32xl\:gr-prose-lg ol > li {
		padding-left: 1.6666667em;
	}
	.\32xl\:gr-prose-lg ol > li::before {
		left: 0;
	}
	.\32xl\:gr-prose-lg ul > li {
		padding-left: 1.6666667em;
	}
	.\32xl\:gr-prose-lg ul > li::before {
		width: 0.3333333em;
		height: 0.3333333em;
		top: calc(0.8888889em - 0.1666667em);
		left: 0.2222222em;
	}
	.\32xl\:gr-prose-lg > ul > li p {
		margin-top: 0.8888889em;
		margin-bottom: 0.8888889em;
	}
	.\32xl\:gr-prose-lg > ul > li > :first-child {
		margin-top: 1.3333333em;
	}
	.\32xl\:gr-prose-lg > ul > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.\32xl\:gr-prose-lg > ol > li > :first-child {
		margin-top: 1.3333333em;
	}
	.\32xl\:gr-prose-lg > ol > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.\32xl\:gr-prose-lg ol ol,
	.\32xl\:gr-prose-lg ol ul,
	.\32xl\:gr-prose-lg ul ol,
	.\32xl\:gr-prose-lg ul ul {
		margin-top: 0.8888889em;
		margin-bottom: 0.8888889em;
	}
	.\32xl\:gr-prose-lg hr {
		margin-top: 3.1111111em;
		margin-bottom: 3.1111111em;
	}
	.\32xl\:gr-prose-lg hr + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose-lg h2 + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose-lg h3 + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose-lg h4 + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose-lg table {
		font-size: 0.8888889em;
		line-height: 1.5;
	}
	.\32xl\:gr-prose-lg thead th {
		padding-right: 0.75em;
		padding-bottom: 0.75em;
		padding-left: 0.75em;
	}
	.\32xl\:gr-prose-lg thead th:first-child {
		padding-left: 0;
	}
	.\32xl\:gr-prose-lg thead th:last-child {
		padding-right: 0;
	}
	.\32xl\:gr-prose-lg tbody td {
		padding-top: 0.75em;
		padding-right: 0.75em;
		padding-bottom: 0.75em;
		padding-left: 0.75em;
	}
	.\32xl\:gr-prose-lg tbody td:first-child {
		padding-left: 0;
	}
	.\32xl\:gr-prose-lg tbody td:last-child {
		padding-right: 0;
	}
	.\32xl\:gr-prose-lg > :first-child {
		margin-top: 0;
	}
	.\32xl\:gr-prose-lg > :last-child {
		margin-bottom: 0;
	}
	.\32xl\:gr-prose-xl {
		font-size: 1.25rem;
		line-height: 1.8;
	}
	.\32xl\:gr-prose-xl p {
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.\32xl\:gr-prose-xl [class~="lead"] {
		font-size: 1.2em;
		line-height: 1.5;
		margin-top: 1em;
		margin-bottom: 1em;
	}
	.\32xl\:gr-prose-xl blockquote {
		margin-top: 1.6em;
		margin-bottom: 1.6em;
		padding-left: 1.0666667em;
	}
	.\32xl\:gr-prose-xl h1 {
		font-size: 2.8em;
		margin-top: 0;
		margin-bottom: 0.8571429em;
		line-height: 1;
	}
	.\32xl\:gr-prose-xl h2 {
		font-size: 1.8em;
		margin-top: 1.5555556em;
		margin-bottom: 0.8888889em;
		line-height: 1.1111111;
	}
	.\32xl\:gr-prose-xl h3 {
		font-size: 1.5em;
		margin-top: 1.6em;
		margin-bottom: 0.6666667em;
		line-height: 1.3333333;
	}
	.\32xl\:gr-prose-xl h4 {
		margin-top: 1.8em;
		margin-bottom: 0.6em;
		line-height: 1.6;
	}
	.\32xl\:gr-prose-xl img {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.\32xl\:gr-prose-xl video {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.\32xl\:gr-prose-xl figure {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.\32xl\:gr-prose-xl figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.\32xl\:gr-prose-xl figure figcaption {
		font-size: 0.9em;
		line-height: 1.5555556;
		margin-top: 1em;
	}
	.\32xl\:gr-prose-xl code {
		font-size: 0.9em;
	}
	.\32xl\:gr-prose-xl h2 code {
		font-size: 0.8611111em;
	}
	.\32xl\:gr-prose-xl h3 code {
		font-size: 0.9em;
	}
	.\32xl\:gr-prose-xl pre {
		font-size: 0.9em;
		line-height: 1.7777778;
		margin-top: 2em;
		margin-bottom: 2em;
		border-radius: 0.5rem;
		padding-top: 1.1111111em;
		padding-right: 1.3333333em;
		padding-bottom: 1.1111111em;
		padding-left: 1.3333333em;
	}
	.\32xl\:gr-prose-xl ol {
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.\32xl\:gr-prose-xl ul {
		margin-top: 1.2em;
		margin-bottom: 1.2em;
	}
	.\32xl\:gr-prose-xl li {
		margin-top: 0.6em;
		margin-bottom: 0.6em;
	}
	.\32xl\:gr-prose-xl ol > li {
		padding-left: 1.8em;
	}
	.\32xl\:gr-prose-xl ol > li::before {
		left: 0;
	}
	.\32xl\:gr-prose-xl ul > li {
		padding-left: 1.8em;
	}
	.\32xl\:gr-prose-xl ul > li::before {
		width: 0.35em;
		height: 0.35em;
		top: calc(0.9em - 0.175em);
		left: 0.25em;
	}
	.\32xl\:gr-prose-xl > ul > li p {
		margin-top: 0.8em;
		margin-bottom: 0.8em;
	}
	.\32xl\:gr-prose-xl > ul > li > :first-child {
		margin-top: 1.2em;
	}
	.\32xl\:gr-prose-xl > ul > li > :last-child {
		margin-bottom: 1.2em;
	}
	.\32xl\:gr-prose-xl > ol > li > :first-child {
		margin-top: 1.2em;
	}
	.\32xl\:gr-prose-xl > ol > li > :last-child {
		margin-bottom: 1.2em;
	}
	.\32xl\:gr-prose-xl ol ol,
	.\32xl\:gr-prose-xl ol ul,
	.\32xl\:gr-prose-xl ul ol,
	.\32xl\:gr-prose-xl ul ul {
		margin-top: 0.8em;
		margin-bottom: 0.8em;
	}
	.\32xl\:gr-prose-xl hr {
		margin-top: 2.8em;
		margin-bottom: 2.8em;
	}
	.\32xl\:gr-prose-xl hr + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose-xl h2 + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose-xl h3 + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose-xl h4 + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose-xl table {
		font-size: 0.9em;
		line-height: 1.5555556;
	}
	.\32xl\:gr-prose-xl thead th {
		padding-right: 0.6666667em;
		padding-bottom: 0.8888889em;
		padding-left: 0.6666667em;
	}
	.\32xl\:gr-prose-xl thead th:first-child {
		padding-left: 0;
	}
	.\32xl\:gr-prose-xl thead th:last-child {
		padding-right: 0;
	}
	.\32xl\:gr-prose-xl tbody td {
		padding-top: 0.8888889em;
		padding-right: 0.6666667em;
		padding-bottom: 0.8888889em;
		padding-left: 0.6666667em;
	}
	.\32xl\:gr-prose-xl tbody td:first-child {
		padding-left: 0;
	}
	.\32xl\:gr-prose-xl tbody td:last-child {
		padding-right: 0;
	}
	.\32xl\:gr-prose-xl > :first-child {
		margin-top: 0;
	}
	.\32xl\:gr-prose-xl > :last-child {
		margin-bottom: 0;
	}
	.\32xl\:gr-prose-2xl {
		font-size: 1.5rem;
		line-height: 1.6666667;
	}
	.\32xl\:gr-prose-2xl p {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.\32xl\:gr-prose-2xl [class~="lead"] {
		font-size: 1.25em;
		line-height: 1.4666667;
		margin-top: 1.0666667em;
		margin-bottom: 1.0666667em;
	}
	.\32xl\:gr-prose-2xl blockquote {
		margin-top: 1.7777778em;
		margin-bottom: 1.7777778em;
		padding-left: 1.1111111em;
	}
	.\32xl\:gr-prose-2xl h1 {
		font-size: 2.6666667em;
		margin-top: 0;
		margin-bottom: 0.875em;
		line-height: 1;
	}
	.\32xl\:gr-prose-2xl h2 {
		font-size: 2em;
		margin-top: 1.5em;
		margin-bottom: 0.8333333em;
		line-height: 1.0833333;
	}
	.\32xl\:gr-prose-2xl h3 {
		font-size: 1.5em;
		margin-top: 1.5555556em;
		margin-bottom: 0.6666667em;
		line-height: 1.2222222;
	}
	.\32xl\:gr-prose-2xl h4 {
		margin-top: 1.6666667em;
		margin-bottom: 0.6666667em;
		line-height: 1.5;
	}
	.\32xl\:gr-prose-2xl img {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.\32xl\:gr-prose-2xl video {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.\32xl\:gr-prose-2xl figure {
		margin-top: 2em;
		margin-bottom: 2em;
	}
	.\32xl\:gr-prose-2xl figure > * {
		margin-top: 0;
		margin-bottom: 0;
	}
	.\32xl\:gr-prose-2xl figure figcaption {
		font-size: 0.8333333em;
		line-height: 1.6;
		margin-top: 1em;
	}
	.\32xl\:gr-prose-2xl code {
		font-size: 0.8333333em;
	}
	.\32xl\:gr-prose-2xl h2 code {
		font-size: 0.875em;
	}
	.\32xl\:gr-prose-2xl h3 code {
		font-size: 0.8888889em;
	}
	.\32xl\:gr-prose-2xl pre {
		font-size: 0.8333333em;
		line-height: 1.8;
		margin-top: 2em;
		margin-bottom: 2em;
		border-radius: 0.5rem;
		padding-top: 1.2em;
		padding-right: 1.6em;
		padding-bottom: 1.2em;
		padding-left: 1.6em;
	}
	.\32xl\:gr-prose-2xl ol {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.\32xl\:gr-prose-2xl ul {
		margin-top: 1.3333333em;
		margin-bottom: 1.3333333em;
	}
	.\32xl\:gr-prose-2xl li {
		margin-top: 0.5em;
		margin-bottom: 0.5em;
	}
	.\32xl\:gr-prose-2xl ol > li {
		padding-left: 1.6666667em;
	}
	.\32xl\:gr-prose-2xl ol > li::before {
		left: 0;
	}
	.\32xl\:gr-prose-2xl ul > li {
		padding-left: 1.6666667em;
	}
	.\32xl\:gr-prose-2xl ul > li::before {
		width: 0.3333333em;
		height: 0.3333333em;
		top: calc(0.8333333em - 0.1666667em);
		left: 0.25em;
	}
	.\32xl\:gr-prose-2xl > ul > li p {
		margin-top: 0.8333333em;
		margin-bottom: 0.8333333em;
	}
	.\32xl\:gr-prose-2xl > ul > li > :first-child {
		margin-top: 1.3333333em;
	}
	.\32xl\:gr-prose-2xl > ul > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.\32xl\:gr-prose-2xl > ol > li > :first-child {
		margin-top: 1.3333333em;
	}
	.\32xl\:gr-prose-2xl > ol > li > :last-child {
		margin-bottom: 1.3333333em;
	}
	.\32xl\:gr-prose-2xl ol ol,
	.\32xl\:gr-prose-2xl ol ul,
	.\32xl\:gr-prose-2xl ul ol,
	.\32xl\:gr-prose-2xl ul ul {
		margin-top: 0.6666667em;
		margin-bottom: 0.6666667em;
	}
	.\32xl\:gr-prose-2xl hr {
		margin-top: 3em;
		margin-bottom: 3em;
	}
	.\32xl\:gr-prose-2xl hr + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose-2xl h2 + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose-2xl h3 + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose-2xl h4 + * {
		margin-top: 0;
	}
	.\32xl\:gr-prose-2xl table {
		font-size: 0.8333333em;
		line-height: 1.4;
	}
	.\32xl\:gr-prose-2xl thead th {
		padding-right: 0.6em;
		padding-bottom: 0.8em;
		padding-left: 0.6em;
	}
	.\32xl\:gr-prose-2xl thead th:first-child {
		padding-left: 0;
	}
	.\32xl\:gr-prose-2xl thead th:last-child {
		padding-right: 0;
	}
	.\32xl\:gr-prose-2xl tbody td {
		padding-top: 0.8em;
		padding-right: 0.6em;
		padding-bottom: 0.8em;
		padding-left: 0.6em;
	}
	.\32xl\:gr-prose-2xl tbody td:first-child {
		padding-left: 0;
	}
	.\32xl\:gr-prose-2xl tbody td:last-child {
		padding-right: 0;
	}
	.\32xl\:gr-prose-2xl > :first-child {
		margin-top: 0;
	}
	.\32xl\:gr-prose-2xl > :last-child {
		margin-bottom: 0;
	}
	.\32xl\:gr-prose-red a {
		color: #dc2626;
	}
	.\32xl\:gr-prose-red a code {
		color: #dc2626;
	}
	.\32xl\:gr-prose-yellow a {
		color: #d97706;
	}
	.\32xl\:gr-prose-yellow a code {
		color: #d97706;
	}
	.\32xl\:gr-prose-green a {
		color: #059669;
	}
	.\32xl\:gr-prose-green a code {
		color: #059669;
	}
	.\32xl\:gr-prose-blue a {
		color: #2563eb;
	}
	.\32xl\:gr-prose-blue a code {
		color: #2563eb;
	}
	.\32xl\:gr-prose-indigo a {
		color: #4f46e5;
	}
	.\32xl\:gr-prose-indigo a code {
		color: #4f46e5;
	}
	.\32xl\:gr-prose-purple a {
		color: #7c3aed;
	}
	.\32xl\:gr-prose-purple a code {
		color: #7c3aed;
	}
	.\32xl\:gr-prose-pink a {
		color: #db2777;
	}
	.\32xl\:gr-prose-pink a code {
		color: #db2777;
	}
}
